<?php

class Skyhaus_Font_Icons
{
	static $_instance;
	static $_icons;
	static $enqueued;
	private $picked_types = array();

	static function get_instance()
	{
		if (is_null(self::$_instance)) {
			self::$_instance = new self();
		}

		return self::$_instance;
	}

	/**
	 * Get support icons
	 *
	 * @return array
	 */
	function get_icons()
	{
		if (is_null(self::$_icons)) {
			$ver = get_option('skyhaus_fa_ver', 'v4');

			$icons = [];

			$icons['font-awesome-v456'] = array(
				'name'         => esc_html__('Font Awesome v6', 'skyhaus'),
				'icons'        => $this->get_font_awesome_icons6(),
				'url'          => array(
					'font-awesome' => esc_url(get_template_directory_uri()) . '/assets/vendor/font-awesome/all.min.css',
				),
				'class_config' => '__icon_name__',
			);
		
			$icons['linear-icons-v100'] = array(
				'name'         => esc_html__('Linear Icons (Free)', 'skyhaus'),
				'icons'        => $this->get_linear_icons_icons(),
				'url'          => array(
					'linear-icons' => esc_url(get_template_directory_uri()) . '/assets/vendor/linear-icons/linear-icons.css',
				),
				'class_config' => '__icon_name__',
			);

			self::$_icons = apply_filters('skyhaus/customizer/font_icons', $icons);
		}

		return self::$_icons;
	}

	function is_used()
	{
		if (is_customize_preview()) {
			return true;
		}
		$check = apply_filters('skyhaus/load-icons', true);
		if (is_null($check)) {
			$builders = array('header_builder_panel', 'footer_builder_panel');
			$list     = apply_filters('skyhaus/icon_used', array());

			foreach ($builders as $setting_key) {
				$data = Skyhaus()->get_setting($setting_key);
				if (is_array($data)) {
					foreach ($data as $devices => $rows) {
						foreach ((array) $rows as $row_id => $items) {
							foreach ((array) $items as $item) {
								if (is_array($item)) {
									if (isset($list[$item['id']]) && $list[$item['id']]) {
										return true;
									}
								}
							}
						}
					}
				}
			}
		}

		return $check;
	}

	function enqueue()
	{
		if ($this->is_used()) {
			if (is_null(self::$enqueued)) {
				/**
				 * @since 0.3.9
				 */
				wp_dequeue_style('awf-fontawesome');
				foreach ($this->get_icons() as $icon_id => $icon) {
					if (!is_array($icon['url'])) {
						wp_dequeue_style($icon_id);
						wp_enqueue_style($icon_id, $icon['url'], array(), '5.0.0');
					} else {
						foreach ($icon['url'] as $id => $url) {
							wp_dequeue_style($id);
							wp_enqueue_style($id, $url, array(), '5.0.0');
						}
					}
				}
				self::$enqueued = true;
			}
		}
	}


	function get_font_awesome_icons6()
	{
		return
			array(
			'fab fa-500px' => 'fab fa-500px',
		    'fab fa-accessible-icon' => 'fab fa-accessible-icon',
		    'fab fa-accusoft' => 'fab fa-accusoft',
		    'fab fa-acquisitions-incorporated' => 'fab fa-acquisitions-incorporated',
		    'fas fa-ad' => 'fas fa-ad',
		    'fas fa-address-book' => 'fas fa-address-book',
		    'fas fa-address-card' => 'fas fa-address-card',
		    'fas fa-adjust' => 'fas fa-adjust',
		    'fab fa-adn' => 'fab fa-adn',
		    'fab fa-adversal' => 'fab fa-adversal',
		    'fab fa-affiliatetheme' => 'fab fa-affiliatetheme',
		    'fas fa-air-freshener' => 'fas fa-air-freshener',
		    'fab fa-airbnb' => 'fab fa-airbnb',
		    'fab fa-algolia' => 'fab fa-algolia',
		    'fas fa-align-center' => 'fas fa-align-center',
		    'fas fa-align-justify' => 'fas fa-align-justify',
		    'fas fa-align-left' => 'fas fa-align-left',
		    'fas fa-align-right' => 'fas fa-align-right',
		    'fab fa-alipay' => 'fab fa-alipay',
		    'fas fa-allergies' => 'fas fa-allergies',
		    'fab fa-amazon' => 'fab fa-amazon',
		    'fab fa-amazon-pay' => 'fab fa-amazon-pay',
		    'fas fa-ambulance' => 'fas fa-ambulance',
		    'fas fa-american-sign-language-interpreti' => 'fas fa-american-sign-language-interpreting',
		    'fab fa-amilia' => 'fab fa-amilia',
		    'fas fa-anchor' => 'fas fa-anchor',
		    'fab fa-android' => 'fab fa-android',
		    'fab fa-angellist' => 'fab fa-angellist',
		    'fas fa-angle-double-down' => 'fas fa-angle-double-down',
		    'fas fa-angle-double-left' => 'fas fa-angle-double-left',
		    'fas fa-angle-double-right' => 'fas fa-angle-double-right',
		    'fas fa-angle-double-up' => 'fas fa-angle-double-up',
		    'fas fa-angle-down' => 'fas fa-angle-down',
		    'fas fa-angle-left' => 'fas fa-angle-left',
		    'fas fa-angle-right' => 'fas fa-angle-right',
		    'fas fa-angle-up' => 'fas fa-angle-up',
		    'fas fa-angry' => 'fas fa-angry',
		    'fab fa-angrycreative' => 'fab fa-angrycreative',
		    'fab fa-angular' => 'fab fa-angular',
		    'fas fa-ankh' => 'fas fa-ankh',
		    'fab fa-app-store' => 'fab fa-app-store',
		    'fab fa-app-store-ios' => 'fab fa-app-store-ios',
		    'fab fa-apper' => 'fab fa-apper',
		    'fab fa-apple' => 'fab fa-apple',
		    'fas fa-apple-alt' => 'fas fa-apple-alt',
		    'fab fa-apple-pay' => 'fab fa-apple-pay',
		    'fas fa-archive' => 'fas fa-archive',
		    'fas fa-archway' => 'fas fa-archway',
		    'fas fa-arrow-alt-circle-down' => 'fas fa-arrow-alt-circle-down',
		    'fas fa-arrow-alt-circle-left' => 'fas fa-arrow-alt-circle-left',
		    'fas fa-arrow-alt-circle-right' => 'fas fa-arrow-alt-circle-right',
		    'fas fa-arrow-alt-circle-up' => 'fas fa-arrow-alt-circle-up',
		    'fas fa-arrow-circle-down' => 'fas fa-arrow-circle-down',
		    'fas fa-arrow-circle-left' => 'fas fa-arrow-circle-left',
		    'fas fa-arrow-circle-right' => 'fas fa-arrow-circle-right',
		    'fas fa-arrow-circle-up' => 'fas fa-arrow-circle-up',
		    'fas fa-arrow-down' => 'fas fa-arrow-down',
		    'fas fa-arrow-left' => 'fas fa-arrow-left',
		    'fas fa-arrow-right' => 'fas fa-arrow-right',
		    'fas fa-arrow-up' => 'fas fa-arrow-up',
		    'fas fa-arrows-alt' => 'fas fa-arrows-alt',
		    'fas fa-arrows-alt-h' => 'fas fa-arrows-alt-h',
		    'fas fa-arrows-alt-v' => 'fas fa-arrows-alt-v',
		    'fab fa-artstation' => 'fab fa-artstation',
		    'fas fa-assistive-listening-systems' => 'fas fa-assistive-listening-systems',
		    'fas fa-asterisk' => 'fas fa-asterisk',
		    'fab fa-asymmetrik' => 'fab fa-asymmetrik',
		    'fas fa-at' => 'fas fa-at',
		    'fas fa-atlas' => 'fas fa-atlas',
		    'fab fa-atlassian' => 'fab fa-atlassian',
		    'fas fa-atom' => 'fas fa-atom',
		    'fab fa-audible' => 'fab fa-audible',
		    'fas fa-audio-description' => 'fas fa-audio-description',
		    'fab fa-autoprefixer' => 'fab fa-autoprefixer',
		    'fab fa-avianex' => 'fab fa-avianex',
		    'fab fa-aviato' => 'fab fa-aviato',
		    'fas fa-award' => 'fas fa-award',
		    'fab fa-aws' => 'fab fa-aws',
		    'fas fa-baby' => 'fas fa-baby',
		    'fas fa-baby-carriage' => 'fas fa-baby-carriage',
		    'fas fa-backspace' => 'fas fa-backspace',
		    'fas fa-backward' => 'fas fa-backward',
		    'fas fa-bacon' => 'fas fa-bacon',
		    'fas fa-balance-scale' => 'fas fa-balance-scale',
		    'fas fa-balance-scale-left' => 'fas fa-balance-scale-left',
		    'fas fa-balance-scale-right' => 'fas fa-balance-scale-right',
		    'fas fa-ban' => 'fas fa-ban',
		    'fas fa-band-aid' => 'fas fa-band-aid',
		    'fab fa-bandcamp' => 'fab fa-bandcamp',
		    'fas fa-barcode' => 'fas fa-barcode',
		    'fas fa-bars' => 'fas fa-bars',
		    'fas fa-baseball-ball' => 'fas fa-baseball-ball',
		    'fas fa-basketball-ball' => 'fas fa-basketball-ball',
		    'fas fa-bath' => 'fas fa-bath',
		    'fas fa-battery-empty' => 'fas fa-battery-empty',
		    'fas fa-battery-full' => 'fas fa-battery-full',
		    'fas fa-battery-half' => 'fas fa-battery-half',
		    'fas fa-battery-quarter' => 'fas fa-battery-quarter',
		    'fas fa-battery-three-quarters' => 'fas fa-battery-three-quarters',
		    'fab fa-battle-net' => 'fab fa-battle-net',
		    'fas fa-bed' => 'fas fa-bed',
		    'fas fa-beer' => 'fas fa-beer',
		    'fab fa-behance' => 'fab fa-behance',
		    'fab fa-behance-square' => 'fab fa-behance-square',
		    'fas fa-bell' => 'fas fa-bell',
		    'fas fa-bell-slash' => 'fas fa-bell-slash',
		    'fas fa-bezier-curve' => 'fas fa-bezier-curve',
		    'fas fa-bible' => 'fas fa-bible',
		    'fas fa-bicycle' => 'fas fa-bicycle',
		    'fas fa-biking' => 'fas fa-biking',
		    'fab fa-bimobject' => 'fab fa-bimobject',
		    'fas fa-binoculars' => 'fas fa-binoculars',
		    'fas fa-biohazard' => 'fas fa-biohazard',
		    'fas fa-birthday-cake' => 'fas fa-birthday-cake',
		    'fab fa-bitbucket' => 'fab fa-bitbucket',
		    'fab fa-bitcoin' => 'fab fa-bitcoin',
		    'fab fa-bity' => 'fab fa-bity',
		    'fab fa-black-tie' => 'fab fa-black-tie',
		    'fab fa-blackberry' => 'fab fa-blackberry',
		    'fas fa-blender' => 'fas fa-blender',
		    'fas fa-blender-phone' => 'fas fa-blender-phone',
		    'fas fa-blind' => 'fas fa-blind',
		    'fas fa-blog' => 'fas fa-blog',
		    'fab fa-blogger' => 'fab fa-blogger',
		    'fab fa-blogger-b' => 'fab fa-blogger-b',
		    'fab fa-bluetooth' => 'fab fa-bluetooth',
		    'fab fa-bluetooth-b' => 'fab fa-bluetooth-b',
		    'fas fa-bold' => 'fas fa-bold',
		    'fas fa-bolt' => 'fas fa-bolt',
		    'fas fa-bomb' => 'fas fa-bomb',
		    'fas fa-bone' => 'fas fa-bone',
		    'fas fa-bong' => 'fas fa-bong',
		    'fas fa-book' => 'fas fa-book',
		    'fas fa-book-dead' => 'fas fa-book-dead',
		    'fas fa-book-medical' => 'fas fa-book-medical',
		    'fas fa-book-open' => 'fas fa-book-open',
		    'fas fa-book-reader' => 'fas fa-book-reader',
		    'fas fa-bookmark' => 'fas fa-bookmark',
		    'fab fa-bootstrap' => 'fab fa-bootstrap',
		    'fas fa-border-all' => 'fas fa-border-all',
		    'fas fa-border-none' => 'fas fa-border-none',
		    'fas fa-border-style' => 'fas fa-border-style',
		    'fas fa-bowling-ball' => 'fas fa-bowling-ball',
		    'fas fa-box' => 'fas fa-box',
		    'fas fa-box-open' => 'fas fa-box-open',
		    'fas fa-boxes' => 'fas fa-boxes',
		    'fas fa-braille' => 'fas fa-braille',
		    'fas fa-brain' => 'fas fa-brain',
		    'fas fa-bread-slice' => 'fas fa-bread-slice',
		    'fas fa-briefcase' => 'fas fa-briefcase',
		    'fas fa-briefcase-medical' => 'fas fa-briefcase-medical',
		    'fas fa-broadcast-tower' => 'fas fa-broadcast-tower',
		    'fas fa-broom' => 'fas fa-broom',
		    'fas fa-brush' => 'fas fa-brush',
		    'fab fa-btc' => 'fab fa-btc',
		    'fab fa-buffer' => 'fab fa-buffer',
		    'fas fa-bug' => 'fas fa-bug',
		    'fas fa-building' => 'fas fa-building',
		    'fas fa-bullhorn' => 'fas fa-bullhorn',
		    'fas fa-bullseye' => 'fas fa-bullseye',
		    'fas fa-burn' => 'fas fa-burn',
		    'fab fa-buromobelexperte' => 'fab fa-buromobelexperte',
		    'fas fa-bus' => 'fas fa-bus',
		    'fas fa-bus-alt' => 'fas fa-bus-alt',
		    'fas fa-business-time' => 'fas fa-business-time',
		    'fab fa-buysellads' => 'fab fa-buysellads',
		    'fas fa-calculator' => 'fas fa-calculator',
		    'fas fa-calendar' => 'fas fa-calendar',
		    'fas fa-calendar-alt' => 'fas fa-calendar-alt',
		    'fas fa-calendar-check' => 'fas fa-calendar-check',
		    'fas fa-calendar-day' => 'fas fa-calendar-day',
		    'fas fa-calendar-minus' => 'fas fa-calendar-minus',
		    'fas fa-calendar-plus' => 'fas fa-calendar-plus',
		    'fas fa-calendar-times' => 'fas fa-calendar-times',
		    'fas fa-calendar-week' => 'fas fa-calendar-week',
		    'fas fa-camera' => 'fas fa-camera',
		    'fas fa-camera-retro' => 'fas fa-camera-retro',
		    'fas fa-campground' => 'fas fa-campground',
		    'fab fa-canadian-maple-leaf' => 'fab fa-canadian-maple-leaf',
		    'fas fa-candy-cane' => 'fas fa-candy-cane',
		    'fas fa-cannabis' => 'fas fa-cannabis',
		    'fas fa-capsules' => 'fas fa-capsules',
		    'fas fa-car' => 'fas fa-car',
		    'fas fa-car-alt' => 'fas fa-car-alt',
		    'fas fa-car-battery' => 'fas fa-car-battery',
		    'fas fa-car-crash' => 'fas fa-car-crash',
		    'fas fa-car-side' => 'fas fa-car-side',
		    'fas fa-caret-down' => 'fas fa-caret-down',
		    'fas fa-caret-left' => 'fas fa-caret-left',
		    'fas fa-caret-right' => 'fas fa-caret-right',
		    'fas fa-caret-square-down' => 'fas fa-caret-square-down',
		    'fas fa-caret-square-left' => 'fas fa-caret-square-left',
		    'fas fa-caret-square-right' => 'fas fa-caret-square-right',
		    'fas fa-caret-square-up' => 'fas fa-caret-square-up',
		    'fas fa-caret-up' => 'fas fa-caret-up',
		    'fas fa-carrot' => 'fas fa-carrot',
		    'fas fa-cart-arrow-down' => 'fas fa-cart-arrow-down',
		    'fas fa-cart-plus' => 'fas fa-cart-plus',
		    'fas fa-cash-register' => 'fas fa-cash-register',
		    'fas fa-cat' => 'fas fa-cat',
		    'fab fa-cc-amazon-pay' => 'fab fa-cc-amazon-pay',
		    'fab fa-cc-amex' => 'fab fa-cc-amex',
		    'fab fa-cc-apple-pay' => 'fab fa-cc-apple-pay',
		    'fab fa-cc-diners-club' => 'fab fa-cc-diners-club',
		    'fab fa-cc-discover' => 'fab fa-cc-discover',
		    'fab fa-cc-jcb' => 'fab fa-cc-jcb',
		    'fab fa-cc-mastercard' => 'fab fa-cc-mastercard',
		    'fab fa-cc-paypal' => 'fab fa-cc-paypal',
		    'fab fa-cc-stripe' => 'fab fa-cc-stripe',
		    'fab fa-cc-visa' => 'fab fa-cc-visa',
		    'fab fa-centercode' => 'fab fa-centercode',
		    'fab fa-centos' => 'fab fa-centos',
		    'fas fa-certificate' => 'fas fa-certificate',
		    'fas fa-chair' => 'fas fa-chair',
		    'fas fa-chalkboard' => 'fas fa-chalkboard',
		    'fas fa-chalkboard-teacher' => 'fas fa-chalkboard-teacher',
		    'fas fa-charging-station' => 'fas fa-charging-station',
		    'fas fa-chart-area' => 'fas fa-chart-area',
		    'fas fa-chart-bar' => 'fas fa-chart-bar',
		    'fas fa-chart-line' => 'fas fa-chart-line',
		    'fas fa-chart-pie' => 'fas fa-chart-pie',
		    'fas fa-check' => 'fas fa-check',
		    'fas fa-check-circle' => 'fas fa-check-circle',
		    'fas fa-check-double' => 'fas fa-check-double',
		    'fas fa-check-square' => 'fas fa-check-square',
		    'fas fa-cheese' => 'fas fa-cheese',
		    'fas fa-chess' => 'fas fa-chess',
		    'fas fa-chess-bishop' => 'fas fa-chess-bishop',
		    'fas fa-chess-board' => 'fas fa-chess-board',
		    'fas fa-chess-king' => 'fas fa-chess-king',
		    'fas fa-chess-knight' => 'fas fa-chess-knight',
		    'fas fa-chess-pawn' => 'fas fa-chess-pawn',
		    'fas fa-chess-queen' => 'fas fa-chess-queen',
		    'fas fa-chess-rook' => 'fas fa-chess-rook',
		    'fas fa-chevron-circle-down' => 'fas fa-chevron-circle-down',
		    'fas fa-chevron-circle-left' => 'fas fa-chevron-circle-left',
		    'fas fa-chevron-circle-right' => 'fas fa-chevron-circle-right',
		    'fas fa-chevron-circle-up' => 'fas fa-chevron-circle-up',
		    'fas fa-chevron-down' => 'fas fa-chevron-down',
		    'fas fa-chevron-left' => 'fas fa-chevron-left',
		    'fas fa-chevron-right' => 'fas fa-chevron-right',
		    'fas fa-chevron-up' => 'fas fa-chevron-up',
		    'fas fa-child' => 'fas fa-child',
		    'fab fa-chrome' => 'fab fa-chrome',
		    'fab fa-chromecast' => 'fab fa-chromecast',
		    'fas fa-church' => 'fas fa-church',
		    'fas fa-circle' => 'fas fa-circle',
		    'fas fa-circle-notch' => 'fas fa-circle-notch',
		    'fas fa-city' => 'fas fa-city',
		    'fas fa-clinic-medical' => 'fas fa-clinic-medical',
		    'fas fa-clipboard' => 'fas fa-clipboard',
		    'fas fa-clipboard-check' => 'fas fa-clipboard-check',
		    'fas fa-clipboard-list' => 'fas fa-clipboard-list',
		    'fas fa-clock' => 'fas fa-clock',
		    'fas fa-clone' => 'fas fa-clone',
		    'fas fa-closed-captioning' => 'fas fa-closed-captioning',
		    'fas fa-cloud' => 'fas fa-cloud',
		    'fas fa-cloud-download-alt' => 'fas fa-cloud-download-alt',
		    'fas fa-cloud-meatball' => 'fas fa-cloud-meatball',
		    'fas fa-cloud-moon' => 'fas fa-cloud-moon',
		    'fas fa-cloud-moon-rain' => 'fas fa-cloud-moon-rain',
		    'fas fa-cloud-rain' => 'fas fa-cloud-rain',
		    'fas fa-cloud-showers-heavy' => 'fas fa-cloud-showers-heavy',
		    'fas fa-cloud-sun' => 'fas fa-cloud-sun',
		    'fas fa-cloud-sun-rain' => 'fas fa-cloud-sun-rain',
		    'fas fa-cloud-upload-alt' => 'fas fa-cloud-upload-alt',
		    'fab fa-cloudscale' => 'fab fa-cloudscale',
		    'fab fa-cloudsmith' => 'fab fa-cloudsmith',
		    'fab fa-cloudversify' => 'fab fa-cloudversify',
		    'fas fa-cocktail' => 'fas fa-cocktail',
		    'fas fa-code' => 'fas fa-code',
		    'fas fa-code-branch' => 'fas fa-code-branch',
		    'fab fa-codepen' => 'fab fa-codepen',
		    'fab fa-codiepie' => 'fab fa-codiepie',
		    'fas fa-coffee' => 'fas fa-coffee',
		    'fas fa-cog' => 'fas fa-cog',
		    'fas fa-cogs' => 'fas fa-cogs',
		    'fas fa-coins' => 'fas fa-coins',
		    'fas fa-columns' => 'fas fa-columns',
		    'fas fa-comment' => 'fas fa-comment',
		    'fas fa-comment-alt' => 'fas fa-comment-alt',
		    'fas fa-comment-dollar' => 'fas fa-comment-dollar',
		    'fas fa-comment-dots' => 'fas fa-comment-dots',
		    'fas fa-comment-medical' => 'fas fa-comment-medical',
		    'fas fa-comment-slash' => 'fas fa-comment-slash',
		    'fas fa-comments' => 'fas fa-comments',
		    'fas fa-comments-dollar' => 'fas fa-comments-dollar',
		    'fas fa-compact-disc' => 'fas fa-compact-disc',
		    'fas fa-compass' => 'fas fa-compass',
		    'fas fa-compress' => 'fas fa-compress',
		    'fas fa-compress-arrows-alt' => 'fas fa-compress-arrows-alt',
		    'fas fa-concierge-bell' => 'fas fa-concierge-bell',
		    'fab fa-confluence' => 'fab fa-confluence',
		    'fab fa-connectdevelop' => 'fab fa-connectdevelop',
		    'fab fa-contao' => 'fab fa-contao',
		    'fas fa-cookie' => 'fas fa-cookie',
		    'fas fa-cookie-bite' => 'fas fa-cookie-bite',
		    'fas fa-copy' => 'fas fa-copy',
		    'fas fa-copyright' => 'fas fa-copyright',
		    'fab fa-cotton-bureau' => 'fab fa-cotton-bureau',
		    'fas fa-couch' => 'fas fa-couch',
		    'fab fa-cpanel' => 'fab fa-cpanel',
		    'fab fa-creative-commons' => 'fab fa-creative-commons',
		    'fab fa-creative-commons-by' => 'fab fa-creative-commons-by',
		    'fab fa-creative-commons-nc' => 'fab fa-creative-commons-nc',
		    'fab fa-creative-commons-nc-eu' => 'fab fa-creative-commons-nc-eu',
		    'fab fa-creative-commons-nc-jp' => 'fab fa-creative-commons-nc-jp',
		    'fab fa-creative-commons-nd' => 'fab fa-creative-commons-nd',
		    'fab fa-creative-commons-pd' => 'fab fa-creative-commons-pd',
		    'fab fa-creative-commons-pd-alt' => 'fab fa-creative-commons-pd-alt',
		    'fab fa-creative-commons-remix' => 'fab fa-creative-commons-remix',
		    'fab fa-creative-commons-sa' => 'fab fa-creative-commons-sa',
		    'fab fa-creative-commons-sampling' => 'fab fa-creative-commons-sampling',
		    'fab fa-creative-commons-sampling-plus' => 'fab fa-creative-commons-sampling-plus',
		    'fab fa-creative-commons-share' => 'fab fa-creative-commons-share',
		    'fab fa-creative-commons-zero' => 'fab fa-creative-commons-zero',
		    'fas fa-credit-card' => 'fas fa-credit-card',
		    'fab fa-critical-role' => 'fab fa-critical-role',
		    'fas fa-crop' => 'fas fa-crop',
		    'fas fa-crop-alt' => 'fas fa-crop-alt',
		    'fas fa-cross' => 'fas fa-cross',
		    'fas fa-crosshairs' => 'fas fa-crosshairs',
		    'fas fa-crow' => 'fas fa-crow',
		    'fas fa-crown' => 'fas fa-crown',
		    'fas fa-crutch' => 'fas fa-crutch',
		    'fab fa-css3' => 'fab fa-css3',
		    'fab fa-css3-alt' => 'fab fa-css3-alt',
		    'fas fa-cube' => 'fas fa-cube',
		    'fas fa-cubes' => 'fas fa-cubes',
		    'fas fa-cut' => 'fas fa-cut',
		    'fab fa-cuttlefish' => 'fab fa-cuttlefish',
		    'fab fa-d-and-d' => 'fab fa-d-and-d',
		    'fab fa-d-and-d-beyond' => 'fab fa-d-and-d-beyond',
		    'fab fa-dashcube' => 'fab fa-dashcube',
		    'fas fa-database' => 'fas fa-database',
		    'fas fa-deaf' => 'fas fa-deaf',
		    'fab fa-delicious' => 'fab fa-delicious',
		    'fas fa-democrat' => 'fas fa-democrat',
		    'fab fa-deploydog' => 'fab fa-deploydog',
		    'fab fa-deskpro' => 'fab fa-deskpro',
		    'fas fa-desktop' => 'fas fa-desktop',
		    'fab fa-dev' => 'fab fa-dev',
		    'fab fa-deviantart' => 'fab fa-deviantart',
		    'fas fa-dharmachakra' => 'fas fa-dharmachakra',
		    'fab fa-dhl' => 'fab fa-dhl',
		    'fas fa-diagnoses' => 'fas fa-diagnoses',
		    'fab fa-diaspora' => 'fab fa-diaspora',
		    'fas fa-dice' => 'fas fa-dice',
		    'fas fa-dice-d20' => 'fas fa-dice-d20',
		    'fas fa-dice-d6' => 'fas fa-dice-d6',
		    'fas fa-dice-five' => 'fas fa-dice-five',
		    'fas fa-dice-four' => 'fas fa-dice-four',
		    'fas fa-dice-one' => 'fas fa-dice-one',
		    'fas fa-dice-six' => 'fas fa-dice-six',
		    'fas fa-dice-three' => 'fas fa-dice-three',
		    'fas fa-dice-two' => 'fas fa-dice-two',
		    'fab fa-digg' => 'fab fa-digg',
		    'fab fa-digital-ocean' => 'fab fa-digital-ocean',
		    'fas fa-digital-tachograph' => 'fas fa-digital-tachograph',
		    'fas fa-directions' => 'fas fa-directions',
		    'fab fa-discord' => 'fab fa-discord',
		    'fab fa-discourse' => 'fab fa-discourse',
		    'fas fa-divide' => 'fas fa-divide',
		    'fas fa-dizzy' => 'fas fa-dizzy',
		    'fas fa-dna' => 'fas fa-dna',
		    'fab fa-dochub' => 'fab fa-dochub',
		    'fab fa-docker' => 'fab fa-docker',
		    'fas fa-dog' => 'fas fa-dog',
		    'fas fa-dollar-sign' => 'fas fa-dollar-sign',
		    'fas fa-dolly' => 'fas fa-dolly',
		    'fas fa-dolly-flatbed' => 'fas fa-dolly-flatbed',
		    'fas fa-donate' => 'fas fa-donate',
		    'fas fa-door-closed' => 'fas fa-door-closed',
		    'fas fa-door-open' => 'fas fa-door-open',
		    'fas fa-dot-circle' => 'fas fa-dot-circle',
		    'fas fa-dove' => 'fas fa-dove',
		    'fas fa-download' => 'fas fa-download',
		    'fab fa-draft2digital' => 'fab fa-draft2digital',
		    'fas fa-drafting-compass' => 'fas fa-drafting-compass',
		    'fas fa-dragon' => 'fas fa-dragon',
		    'fas fa-draw-polygon' => 'fas fa-draw-polygon',
		    'fab fa-dribbble' => 'fab fa-dribbble',
		    'fab fa-dribbble-square' => 'fab fa-dribbble-square',
		    'fab fa-dropbox' => 'fab fa-dropbox',
		    'fas fa-drum' => 'fas fa-drum',
		    'fas fa-drum-steelpan' => 'fas fa-drum-steelpan',
		    'fas fa-drumstick-bite' => 'fas fa-drumstick-bite',
		    'fab fa-drupal' => 'fab fa-drupal',
		    'fas fa-dumbbell' => 'fas fa-dumbbell',
		    'fas fa-dumpster' => 'fas fa-dumpster',
		    'fas fa-dumpster-fire' => 'fas fa-dumpster-fire',
		    'fas fa-dungeon' => 'fas fa-dungeon',
		    'fab fa-dyalog' => 'fab fa-dyalog',
		    'fab fa-earlybirds' => 'fab fa-earlybirds',
		    'fab fa-ebay' => 'fab fa-ebay',
		    'fab fa-edge' => 'fab fa-edge',
		    'fas fa-edit' => 'fas fa-edit',
		    'fas fa-egg' => 'fas fa-egg',
		    'fas fa-eject' => 'fas fa-eject',
		    'fab fa-elementor' => 'fab fa-elementor',
		    'fas fa-ellipsis-h' => 'fas fa-ellipsis-h',
		    'fas fa-ellipsis-v' => 'fas fa-ellipsis-v',
		    'fab fa-ello' => 'fab fa-ello',
		    'fab fa-ember' => 'fab fa-ember',
		    'fab fa-empire' => 'fab fa-empire',
		    'fas fa-envelope' => 'fas fa-envelope',
		    'fas fa-envelope-open' => 'fas fa-envelope-open',
		    'fas fa-envelope-open-text' => 'fas fa-envelope-open-text',
		    'fas fa-envelope-square' => 'fas fa-envelope-square',
		    'fab fa-envira' => 'fab fa-envira',
		    'fas fa-equals' => 'fas fa-equals',
		    'fas fa-eraser' => 'fas fa-eraser',
		    'fab fa-erlang' => 'fab fa-erlang',
		    'fab fa-ethereum' => 'fab fa-ethereum',
		    'fas fa-ethernet' => 'fas fa-ethernet',
		    'fab fa-etsy' => 'fab fa-etsy',
		    'fas fa-euro-sign' => 'fas fa-euro-sign',
		    'fab fa-evernote' => 'fab fa-evernote',
		    'fas fa-exchange-alt' => 'fas fa-exchange-alt',
		    'fas fa-exclamation' => 'fas fa-exclamation',
		    'fas fa-exclamation-circle' => 'fas fa-exclamation-circle',
		    'fas fa-exclamation-triangle' => 'fas fa-exclamation-triangle',
		    'fas fa-expand' => 'fas fa-expand',
		    'fas fa-expand-arrows-alt' => 'fas fa-expand-arrows-alt',
		    'fab fa-expeditedssl' => 'fab fa-expeditedssl',
		    'fas fa-external-link-alt' => 'fas fa-external-link-alt',
		    'fas fa-external-link-square-alt' => 'fas fa-external-link-square-alt',
		    'fas fa-eye' => 'fas fa-eye',
		    'fas fa-eye-dropper' => 'fas fa-eye-dropper',
		    'fas fa-eye-slash' => 'fas fa-eye-slash',
		    'fab fa-facebook' => 'fab fa-facebook',
		    'fab fa-facebook-f' => 'fab fa-facebook-f',
		    'fab fa-facebook-messenger' => 'fab fa-facebook-messenger',
		    'fab fa-facebook-square' => 'fab fa-facebook-square',
		    'fas fa-fan' => 'fas fa-fan',
		    'fab fa-fantasy-flight-games' => 'fab fa-fantasy-flight-games',
		    'fas fa-fast-backward' => 'fas fa-fast-backward',
		    'fas fa-fast-forward' => 'fas fa-fast-forward',
		    'fas fa-fax' => 'fas fa-fax',
		    'fas fa-feather' => 'fas fa-feather',
		    'fas fa-feather-alt' => 'fas fa-feather-alt',
		    'fab fa-fedex' => 'fab fa-fedex',
		    'fab fa-fedora' => 'fab fa-fedora',
		    'fas fa-female' => 'fas fa-female',
		    'fas fa-fighter-jet' => 'fas fa-fighter-jet',
		    'fab fa-figma' => 'fab fa-figma',
		    'fas fa-file' => 'fas fa-file',
		    'fas fa-file-alt' => 'fas fa-file-alt',
		    'fas fa-file-archive' => 'fas fa-file-archive',
		    'fas fa-file-audio' => 'fas fa-file-audio',
		    'fas fa-file-code' => 'fas fa-file-code',
		    'fas fa-file-contract' => 'fas fa-file-contract',
		    'fas fa-file-csv' => 'fas fa-file-csv',
		    'fas fa-file-download' => 'fas fa-file-download',
		    'fas fa-file-excel' => 'fas fa-file-excel',
		    'fas fa-file-export' => 'fas fa-file-export',
		    'fas fa-file-image' => 'fas fa-file-image',
		    'fas fa-file-import' => 'fas fa-file-import',
		    'fas fa-file-invoice' => 'fas fa-file-invoice',
		    'fas fa-file-invoice-dollar' => 'fas fa-file-invoice-dollar',
		    'fas fa-file-medical' => 'fas fa-file-medical',
		    'fas fa-file-medical-alt' => 'fas fa-file-medical-alt',
		    'fas fa-file-pdf' => 'fas fa-file-pdf',
		    'fas fa-file-powerpoint' => 'fas fa-file-powerpoint',
		    'fas fa-file-prescription' => 'fas fa-file-prescription',
		    'fas fa-file-signature' => 'fas fa-file-signature',
		    'fas fa-file-upload' => 'fas fa-file-upload',
		    'fas fa-file-video' => 'fas fa-file-video',
		    'fas fa-file-word' => 'fas fa-file-word',
		    'fas fa-fill' => 'fas fa-fill',
		    'fas fa-fill-drip' => 'fas fa-fill-drip',
		    'fas fa-film' => 'fas fa-film',
		    'fas fa-filter' => 'fas fa-filter',
		    'fas fa-fingerprint' => 'fas fa-fingerprint',
		    'fas fa-fire' => 'fas fa-fire',
		    'fas fa-fire-alt' => 'fas fa-fire-alt',
		    'fas fa-fire-extinguisher' => 'fas fa-fire-extinguisher',
		    'fab fa-firefox' => 'fab fa-firefox',
		    'fas fa-first-aid' => 'fas fa-first-aid',
		    'fab fa-first-order' => 'fab fa-first-order',
		    'fab fa-first-order-alt' => 'fab fa-first-order-alt',
		    'fab fa-firstdraft' => 'fab fa-firstdraft',
		    'fas fa-fish' => 'fas fa-fish',
		    'fas fa-fist-raised' => 'fas fa-fist-raised',
		    'fas fa-flag' => 'fas fa-flag',
		    'fas fa-flag-checkered' => 'fas fa-flag-checkered',
		    'fas fa-flag-usa' => 'fas fa-flag-usa',
		    'fas fa-flask' => 'fas fa-flask',
		    'fab fa-flickr' => 'fab fa-flickr',
		    'fab fa-flipboard' => 'fab fa-flipboard',
		    'fas fa-flushed' => 'fas fa-flushed',
		    'fab fa-fly' => 'fab fa-fly',
		    'fas fa-folder' => 'fas fa-folder',
		    'fas fa-folder-minus' => 'fas fa-folder-minus',
		    'fas fa-folder-open' => 'fas fa-folder-open',
		    'fas fa-folder-plus' => 'fas fa-folder-plus',
		    'fas fa-font' => 'fas fa-font',
		    'fab fa-font-awesome' => 'fab fa-font-awesome',
		    'fab fa-font-awesome-alt' => 'fab fa-font-awesome-alt',
		    'fab fa-font-awesome-flag' => 'fab fa-font-awesome-flag',
		    'far fa-font-awesome-logo-full' => 'far fa-font-awesome-logo-full',
		    'fab fa-fonticons' => 'fab fa-fonticons',
		    'fab fa-fonticons-fi' => 'fab fa-fonticons-fi',
		    'fas fa-football-ball' => 'fas fa-football-ball',
		    'fab fa-fort-awesome' => 'fab fa-fort-awesome',
		    'fab fa-fort-awesome-alt' => 'fab fa-fort-awesome-alt',
		    'fab fa-forumbee' => 'fab fa-forumbee',
		    'fas fa-forward' => 'fas fa-forward',
		    'fab fa-foursquare' => 'fab fa-foursquare',
		    'fab fa-free-code-camp' => 'fab fa-free-code-camp',
		    'fab fa-freebsd' => 'fab fa-freebsd',
		    'fas fa-frog' => 'fas fa-frog',
		    'fas fa-frown' => 'fas fa-frown',
		    'fas fa-frown-open' => 'fas fa-frown-open',
		    'fab fa-fulcrum' => 'fab fa-fulcrum',
		    'fas fa-funnel-dollar' => 'fas fa-funnel-dollar',
		    'fas fa-futbol' => 'fas fa-futbol',
		    'fab fa-galactic-republic' => 'fab fa-galactic-republic',
		    'fab fa-galactic-senate' => 'fab fa-galactic-senate',
		    'fas fa-gamepad' => 'fas fa-gamepad',
		    'fas fa-gas-pump' => 'fas fa-gas-pump',
		    'fas fa-gavel' => 'fas fa-gavel',
		    'fas fa-gem' => 'fas fa-gem',
		    'fas fa-genderless' => 'fas fa-genderless',
		    'fab fa-get-pocket' => 'fab fa-get-pocket',
		    'fab fa-gg' => 'fab fa-gg',
		    'fab fa-gg-circle' => 'fab fa-gg-circle',
		    'fas fa-ghost' => 'fas fa-ghost',
		    'fas fa-gift' => 'fas fa-gift',
		    'fas fa-gifts' => 'fas fa-gifts',
		    'fab fa-git' => 'fab fa-git',
		    'fab fa-git-alt' => 'fab fa-git-alt',
		    'fab fa-git-square' => 'fab fa-git-square',
		    'fab fa-github' => 'fab fa-github',
		    'fab fa-github-alt' => 'fab fa-github-alt',
		    'fab fa-github-square' => 'fab fa-github-square',
		    'fab fa-gitkraken' => 'fab fa-gitkraken',
		    'fab fa-gitlab' => 'fab fa-gitlab',
		    'fab fa-gitter' => 'fab fa-gitter',
		    'fas fa-glass-cheers' => 'fas fa-glass-cheers',
		    'fas fa-glass-martini' => 'fas fa-glass-martini',
		    'fas fa-glass-martini-alt' => 'fas fa-glass-martini-alt',
		    'fas fa-glass-whiskey' => 'fas fa-glass-whiskey',
		    'fas fa-glasses' => 'fas fa-glasses',
		    'fab fa-glide' => 'fab fa-glide',
		    'fab fa-glide-g' => 'fab fa-glide-g',
		    'fas fa-globe' => 'fas fa-globe',
		    'fas fa-globe-africa' => 'fas fa-globe-africa',
		    'fas fa-globe-americas' => 'fas fa-globe-americas',
		    'fas fa-globe-asia' => 'fas fa-globe-asia',
		    'fas fa-globe-europe' => 'fas fa-globe-europe',
		    'fab fa-gofore' => 'fab fa-gofore',
		    'fas fa-golf-ball' => 'fas fa-golf-ball',
		    'fab fa-goodreads' => 'fab fa-goodreads',
		    'fab fa-goodreads-g' => 'fab fa-goodreads-g',
		    'fab fa-google' => 'fab fa-google',
		    'fab fa-google-drive' => 'fab fa-google-drive',
		    'fab fa-google-play' => 'fab fa-google-play',
		    'fab fa-google-plus' => 'fab fa-google-plus',
		    'fab fa-google-plus-g' => 'fab fa-google-plus-g',
		    'fab fa-google-plus-square' => 'fab fa-google-plus-square',
		    'fab fa-google-wallet' => 'fab fa-google-wallet',
		    'fas fa-gopuram' => 'fas fa-gopuram',
		    'fas fa-graduation-cap' => 'fas fa-graduation-cap',
		    'fab fa-gratipay' => 'fab fa-gratipay',
		    'fab fa-grav' => 'fab fa-grav',
		    'fas fa-greater-than' => 'fas fa-greater-than',
		    'fas fa-greater-than-equal' => 'fas fa-greater-than-equal',
		    'fas fa-grimace' => 'fas fa-grimace',
		    'fas fa-grin' => 'fas fa-grin',
		    'fas fa-grin-alt' => 'fas fa-grin-alt',
		    'fas fa-grin-beam' => 'fas fa-grin-beam',
		    'fas fa-grin-beam-sweat' => 'fas fa-grin-beam-sweat',
		    'fas fa-grin-hearts' => 'fas fa-grin-hearts',
		    'fas fa-grin-squint' => 'fas fa-grin-squint',
		    'fas fa-grin-squint-tears' => 'fas fa-grin-squint-tears',
		    'fas fa-grin-stars' => 'fas fa-grin-stars',
		    'fas fa-grin-tears' => 'fas fa-grin-tears',
		    'fas fa-grin-tongue' => 'fas fa-grin-tongue',
		    'fas fa-grin-tongue-squint' => 'fas fa-grin-tongue-squint',
		    'fas fa-grin-tongue-wink' => 'fas fa-grin-tongue-wink',
		    'fas fa-grin-wink' => 'fas fa-grin-wink',
		    'fas fa-grip-horizontal' => 'fas fa-grip-horizontal',
		    'fas fa-grip-lines' => 'fas fa-grip-lines',
		    'fas fa-grip-lines-vertical' => 'fas fa-grip-lines-vertical',
		    'fas fa-grip-vertical' => 'fas fa-grip-vertical',
		    'fab fa-gripfire' => 'fab fa-gripfire',
		    'fab fa-grunt' => 'fab fa-grunt',
		    'fas fa-guitar' => 'fas fa-guitar',
		    'fab fa-gulp' => 'fab fa-gulp',
		    'fas fa-h-square' => 'fas fa-h-square',
		    'fab fa-hacker-news' => 'fab fa-hacker-news',
		    'fab fa-hacker-news-square' => 'fab fa-hacker-news-square',
		    'fab fa-hackerrank' => 'fab fa-hackerrank',
		    'fas fa-hamburger' => 'fas fa-hamburger',
		    'fas fa-hammer' => 'fas fa-hammer',
		    'fas fa-hamsa' => 'fas fa-hamsa',
		    'fas fa-hand-holding' => 'fas fa-hand-holding',
		    'fas fa-hand-holding-heart' => 'fas fa-hand-holding-heart',
		    'fas fa-hand-holding-usd' => 'fas fa-hand-holding-usd',
		    'fas fa-hand-lizard' => 'fas fa-hand-lizard',
		    'fas fa-hand-middle-finger' => 'fas fa-hand-middle-finger',
		    'fas fa-hand-paper' => 'fas fa-hand-paper',
		    'fas fa-hand-peace' => 'fas fa-hand-peace',
		    'fas fa-hand-point-down' => 'fas fa-hand-point-down',
		    'fas fa-hand-point-left' => 'fas fa-hand-point-left',
		    'fas fa-hand-point-right' => 'fas fa-hand-point-right',
		    'fas fa-hand-point-up' => 'fas fa-hand-point-up',
		    'fas fa-hand-pointer' => 'fas fa-hand-pointer',
		    'fas fa-hand-rock' => 'fas fa-hand-rock',
		    'fas fa-hand-scissors' => 'fas fa-hand-scissors',
		    'fas fa-hand-spock' => 'fas fa-hand-spock',
		    'fas fa-hands' => 'fas fa-hands',
		    'fas fa-hands-helping' => 'fas fa-hands-helping',
		    'fas fa-handshake' => 'fas fa-handshake',
		    'fas fa-hanukiah' => 'fas fa-hanukiah',
		    'fas fa-hard-hat' => 'fas fa-hard-hat',
		    'fas fa-hashtag' => 'fas fa-hashtag',
		    'fas fa-hat-wizard' => 'fas fa-hat-wizard',
		    'fas fa-haykal' => 'fas fa-haykal',
		    'fas fa-hdd' => 'fas fa-hdd',
		    'fas fa-heading' => 'fas fa-heading',
		    'fas fa-headphones' => 'fas fa-headphones',
		    'fas fa-headphones-alt' => 'fas fa-headphones-alt',
		    'fas fa-headset' => 'fas fa-headset',
		    'fas fa-heart' => 'fas fa-heart',
		    'fas fa-heart-broken' => 'fas fa-heart-broken',
		    'fas fa-heartbeat' => 'fas fa-heartbeat',
		    'fas fa-helicopter' => 'fas fa-helicopter',
		    'fas fa-highlighter' => 'fas fa-highlighter',
		    'fas fa-hiking' => 'fas fa-hiking',
		    'fas fa-hippo' => 'fas fa-hippo',
		    'fab fa-hips' => 'fab fa-hips',
		    'fab fa-hire-a-helper' => 'fab fa-hire-a-helper',
		    'fas fa-history' => 'fas fa-history',
		    'fas fa-hockey-puck' => 'fas fa-hockey-puck',
		    'fas fa-holly-berry' => 'fas fa-holly-berry',
		    'fas fa-home' => 'fas fa-home',
		    'fab fa-hooli' => 'fab fa-hooli',
		    'fab fa-hornbill' => 'fab fa-hornbill',
		    'fas fa-horse' => 'fas fa-horse',
		    'fas fa-horse-head' => 'fas fa-horse-head',
		    'fas fa-hospital' => 'fas fa-hospital',
		    'fas fa-hospital-alt' => 'fas fa-hospital-alt',
		    'fas fa-hospital-symbol' => 'fas fa-hospital-symbol',
		    'fas fa-hot-tub' => 'fas fa-hot-tub',
		    'fas fa-hotdog' => 'fas fa-hotdog',
		    'fas fa-hotel' => 'fas fa-hotel',
		    'fab fa-hotjar' => 'fab fa-hotjar',
		    'fas fa-hourglass' => 'fas fa-hourglass',
		    'fas fa-hourglass-end' => 'fas fa-hourglass-end',
		    'fas fa-hourglass-half' => 'fas fa-hourglass-half',
		    'fas fa-hourglass-start' => 'fas fa-hourglass-start',
		    'fas fa-house-damage' => 'fas fa-house-damage',
		    'fab fa-houzz' => 'fab fa-houzz',
		    'fas fa-hryvnia' => 'fas fa-hryvnia',
		    'fab fa-html5' => 'fab fa-html5',
		    'fab fa-hubspot' => 'fab fa-hubspot',
		    'fas fa-i-cursor' => 'fas fa-i-cursor',
		    'fas fa-ice-cream' => 'fas fa-ice-cream',
		    'fas fa-icicles' => 'fas fa-icicles',
		    'fas fa-icons' => 'fas fa-icons',
		    'fas fa-id-badge' => 'fas fa-id-badge',
		    'fas fa-id-card' => 'fas fa-id-card',
		    'fas fa-id-card-alt' => 'fas fa-id-card-alt',
		    'fas fa-igloo' => 'fas fa-igloo',
		    'fas fa-image' => 'fas fa-image',
		    'fas fa-images' => 'fas fa-images',
		    'fab fa-imdb' => 'fab fa-imdb',
		    'fas fa-inbox' => 'fas fa-inbox',
		    'fas fa-indent' => 'fas fa-indent',
		    'fas fa-industry' => 'fas fa-industry',
		    'fas fa-infinity' => 'fas fa-infinity',
		    'fas fa-info' => 'fas fa-info',
		    'fas fa-info-circle' => 'fas fa-info-circle',
		    'fab fa-instagram' => 'fab fa-instagram',
		    'fab fa-intercom' => 'fab fa-intercom',
		    'fab fa-internet-explorer' => 'fab fa-internet-explorer',
		    'fab fa-invision' => 'fab fa-invision',
		    'fab fa-ioxhost' => 'fab fa-ioxhost',
		    'fas fa-italic' => 'fas fa-italic',
		    'fab fa-itch-io' => 'fab fa-itch-io',
		    'fab fa-itunes' => 'fab fa-itunes',
		    'fab fa-itunes-note' => 'fab fa-itunes-note',
		    'fab fa-java' => 'fab fa-java',
		    'fas fa-jedi' => 'fas fa-jedi',
		    'fab fa-jedi-order' => 'fab fa-jedi-order',
		    'fab fa-jenkins' => 'fab fa-jenkins',
		    'fab fa-jira' => 'fab fa-jira',
		    'fab fa-joget' => 'fab fa-joget',
		    'fas fa-joint' => 'fas fa-joint',
		    'fab fa-joomla' => 'fab fa-joomla',
		    'fas fa-journal-whills' => 'fas fa-journal-whills',
		    'fab fa-js' => 'fab fa-js',
		    'fab fa-js-square' => 'fab fa-js-square',
		    'fab fa-jsfiddle' => 'fab fa-jsfiddle',
		    'fas fa-kaaba' => 'fas fa-kaaba',
		    'fab fa-kaggle' => 'fab fa-kaggle',
		    'fas fa-key' => 'fas fa-key',
		    'fab fa-keybase' => 'fab fa-keybase',
		    'fas fa-keyboard' => 'fas fa-keyboard',
		    'fab fa-keycdn' => 'fab fa-keycdn',
		    'fas fa-khanda' => 'fas fa-khanda',
		    'fab fa-kickstarter' => 'fab fa-kickstarter',
		    'fab fa-kickstarter-k' => 'fab fa-kickstarter-k',
		    'fas fa-kiss' => 'fas fa-kiss',
		    'fas fa-kiss-beam' => 'fas fa-kiss-beam',
		    'fas fa-kiss-wink-heart' => 'fas fa-kiss-wink-heart',
		    'fas fa-kiwi-bird' => 'fas fa-kiwi-bird',
		    'fab fa-korvue' => 'fab fa-korvue',
		    'fas fa-landmark' => 'fas fa-landmark',
		    'fas fa-language' => 'fas fa-language',
		    'fas fa-laptop' => 'fas fa-laptop',
		    'fas fa-laptop-code' => 'fas fa-laptop-code',
		    'fas fa-laptop-medical' => 'fas fa-laptop-medical',
		    'fab fa-laravel' => 'fab fa-laravel',
		    'fab fa-lastfm' => 'fab fa-lastfm',
		    'fab fa-lastfm-square' => 'fab fa-lastfm-square',
		    'fas fa-laugh' => 'fas fa-laugh',
		    'fas fa-laugh-beam' => 'fas fa-laugh-beam',
		    'fas fa-laugh-squint' => 'fas fa-laugh-squint',
		    'fas fa-laugh-wink' => 'fas fa-laugh-wink',
		    'fas fa-layer-group' => 'fas fa-layer-group',
		    'fas fa-leaf' => 'fas fa-leaf',
		    'fab fa-leanpub' => 'fab fa-leanpub',
		    'fas fa-lemon' => 'fas fa-lemon',
		    'fab fa-less' => 'fab fa-less',
		    'fas fa-less-than' => 'fas fa-less-than',
		    'fas fa-less-than-equal' => 'fas fa-less-than-equal',
		    'fas fa-level-down-alt' => 'fas fa-level-down-alt',
		    'fas fa-level-up-alt' => 'fas fa-level-up-alt',
		    'fas fa-life-ring' => 'fas fa-life-ring',
		    'fas fa-lightbulb' => 'fas fa-lightbulb',
		    'fab fa-line' => 'fab fa-line',
		    'fas fa-link' => 'fas fa-link',
		    'fab fa-linkedin' => 'fab fa-linkedin',
		    'fab fa-linkedin-in' => 'fab fa-linkedin-in',
		    'fab fa-linode' => 'fab fa-linode',
		    'fab fa-linux' => 'fab fa-linux',
		    'fas fa-lira-sign' => 'fas fa-lira-sign',
		    'fas fa-list' => 'fas fa-list',
		    'fas fa-list-alt' => 'fas fa-list-alt',
		    'fas fa-list-ol' => 'fas fa-list-ol',
		    'fas fa-list-ul' => 'fas fa-list-ul',
		    'fas fa-location-arrow' => 'fas fa-location-arrow',
		    'fas fa-lock' => 'fas fa-lock',
		    'fas fa-lock-open' => 'fas fa-lock-open',
		    'fas fa-long-arrow-alt-down' => 'fas fa-long-arrow-alt-down',
		    'fas fa-long-arrow-alt-left' => 'fas fa-long-arrow-alt-left',
		    'fas fa-long-arrow-alt-right' => 'fas fa-long-arrow-alt-right',
		    'fas fa-long-arrow-alt-up' => 'fas fa-long-arrow-alt-up',
		    'fas fa-low-vision' => 'fas fa-low-vision',
		    'fas fa-luggage-cart' => 'fas fa-luggage-cart',
		    'fab fa-lyft' => 'fab fa-lyft',
		    'fab fa-magento' => 'fab fa-magento',
		    'fas fa-magic' => 'fas fa-magic',
		    'fas fa-magnet' => 'fas fa-magnet',
		    'fas fa-mail-bulk' => 'fas fa-mail-bulk',
		    'fab fa-mailchimp' => 'fab fa-mailchimp',
		    'fas fa-male' => 'fas fa-male',
		    'fab fa-mandalorian' => 'fab fa-mandalorian',
		    'fas fa-map' => 'fas fa-map',
		    'fas fa-map-marked' => 'fas fa-map-marked',
		    'fas fa-map-marked-alt' => 'fas fa-map-marked-alt',
		    'fas fa-map-marker' => 'fas fa-map-marker',
		    'fas fa-map-marker-alt' => 'fas fa-map-marker-alt',
		    'fas fa-map-pin' => 'fas fa-map-pin',
		    'fas fa-map-signs' => 'fas fa-map-signs',
		    'fab fa-markdown' => 'fab fa-markdown',
		    'fas fa-marker' => 'fas fa-marker',
		    'fas fa-mars' => 'fas fa-mars',
		    'fas fa-mars-double' => 'fas fa-mars-double',
		    'fas fa-mars-stroke' => 'fas fa-mars-stroke',
		    'fas fa-mars-stroke-h' => 'fas fa-mars-stroke-h',
		    'fas fa-mars-stroke-v' => 'fas fa-mars-stroke-v',
		    'fas fa-mask' => 'fas fa-mask',
		    'fab fa-mastodon' => 'fab fa-mastodon',
		    'fab fa-maxcdn' => 'fab fa-maxcdn',
		    'fas fa-medal' => 'fas fa-medal',
		    'fab fa-medapps' => 'fab fa-medapps',
		    'fab fa-medium' => 'fab fa-medium',
		    'fab fa-medium-m' => 'fab fa-medium-m',
		    'fas fa-medkit' => 'fas fa-medkit',
		    'fab fa-medrt' => 'fab fa-medrt',
		    'fab fa-meetup' => 'fab fa-meetup',
		    'fab fa-megaport' => 'fab fa-megaport',
		    'fas fa-meh' => 'fas fa-meh',
		    'fas fa-meh-blank' => 'fas fa-meh-blank',
		    'fas fa-meh-rolling-eyes' => 'fas fa-meh-rolling-eyes',
		    'fas fa-memory' => 'fas fa-memory',
		    'fab fa-mendeley' => 'fab fa-mendeley',
		    'fas fa-menorah' => 'fas fa-menorah',
		    'fas fa-mercury' => 'fas fa-mercury',
		    'fas fa-meteor' => 'fas fa-meteor',
		    'fas fa-microchip' => 'fas fa-microchip',
		    'fas fa-microphone' => 'fas fa-microphone',
		    'fas fa-microphone-alt' => 'fas fa-microphone-alt',
		    'fas fa-microphone-alt-slash' => 'fas fa-microphone-alt-slash',
		    'fas fa-microphone-slash' => 'fas fa-microphone-slash',
		    'fas fa-microscope' => 'fas fa-microscope',
		    'fab fa-microsoft' => 'fab fa-microsoft',
		    'fas fa-minus' => 'fas fa-minus',
		    'fas fa-minus-circle' => 'fas fa-minus-circle',
		    'fas fa-minus-square' => 'fas fa-minus-square',
		    'fas fa-mitten' => 'fas fa-mitten',
		    'fab fa-mix' => 'fab fa-mix',
		    'fab fa-mixcloud' => 'fab fa-mixcloud',
		    'fab fa-mizuni' => 'fab fa-mizuni',
		    'fas fa-mobile' => 'fas fa-mobile',
		    'fas fa-mobile-alt' => 'fas fa-mobile-alt',
		    'fab fa-modx' => 'fab fa-modx',
		    'fab fa-monero' => 'fab fa-monero',
		    'fas fa-money-bill' => 'fas fa-money-bill',
		    'fas fa-money-bill-alt' => 'fas fa-money-bill-alt',
		    'fas fa-money-bill-wave' => 'fas fa-money-bill-wave',
		    'fas fa-money-bill-wave-alt' => 'fas fa-money-bill-wave-alt',
		    'fas fa-money-check' => 'fas fa-money-check',
		    'fas fa-money-check-alt' => 'fas fa-money-check-alt',
		    'fas fa-monument' => 'fas fa-monument',
		    'fas fa-moon' => 'fas fa-moon',
		    'fas fa-mortar-pestle' => 'fas fa-mortar-pestle',
		    'fas fa-mosque' => 'fas fa-mosque',
		    'fas fa-motorcycle' => 'fas fa-motorcycle',
		    'fas fa-mountain' => 'fas fa-mountain',
		    'fas fa-mouse-pointer' => 'fas fa-mouse-pointer',
		    'fas fa-mug-hot' => 'fas fa-mug-hot',
		    'fas fa-music' => 'fas fa-music',
		    'fab fa-napster' => 'fab fa-napster',
		    'fab fa-neos' => 'fab fa-neos',
		    'fas fa-network-wired' => 'fas fa-network-wired',
		    'fas fa-neuter' => 'fas fa-neuter',
		    'fas fa-newspaper' => 'fas fa-newspaper',
		    'fab fa-nimblr' => 'fab fa-nimblr',
		    'fab fa-node' => 'fab fa-node',
		    'fab fa-node-js' => 'fab fa-node-js',
		    'fas fa-not-equal' => 'fas fa-not-equal',
		    'fas fa-notes-medical' => 'fas fa-notes-medical',
		    'fab fa-npm' => 'fab fa-npm',
		    'fab fa-ns8' => 'fab fa-ns8',
		    'fab fa-nutritionix' => 'fab fa-nutritionix',
		    'fas fa-object-group' => 'fas fa-object-group',
		    'fas fa-object-ungroup' => 'fas fa-object-ungroup',
		    'fab fa-odnoklassniki' => 'fab fa-odnoklassniki',
		    'fab fa-odnoklassniki-square' => 'fab fa-odnoklassniki-square',
		    'fas fa-oil-can' => 'fas fa-oil-can',
		    'fab fa-old-republic' => 'fab fa-old-republic',
		    'fas fa-om' => 'fas fa-om',
		    'fab fa-opencart' => 'fab fa-opencart',
		    'fab fa-openid' => 'fab fa-openid',
		    'fab fa-opera' => 'fab fa-opera',
		    'fab fa-optin-monster' => 'fab fa-optin-monster',
		    'fab fa-osi' => 'fab fa-osi',
		    'fas fa-otter' => 'fas fa-otter',
		    'fas fa-outdent' => 'fas fa-outdent',
		    'fab fa-page4' => 'fab fa-page4',
		    'fab fa-pagelines' => 'fab fa-pagelines',
		    'fas fa-pager' => 'fas fa-pager',
		    'fas fa-paint-brush' => 'fas fa-paint-brush',
		    'fas fa-paint-roller' => 'fas fa-paint-roller',
		    'fas fa-palette' => 'fas fa-palette',
		    'fab fa-palfed' => 'fab fa-palfed',
		    'fas fa-pallet' => 'fas fa-pallet',
		    'fas fa-paper-plane' => 'fas fa-paper-plane',
		    'fas fa-paperclip' => 'fas fa-paperclip',
		    'fas fa-parachute-box' => 'fas fa-parachute-box',
		    'fas fa-paragraph' => 'fas fa-paragraph',
		    'fas fa-parking' => 'fas fa-parking',
		    'fas fa-passport' => 'fas fa-passport',
		    'fas fa-pastafarianism' => 'fas fa-pastafarianism',
		    'fas fa-paste' => 'fas fa-paste',
		    'fab fa-patreon' => 'fab fa-patreon',
		    'fas fa-pause' => 'fas fa-pause',
		    'fas fa-pause-circle' => 'fas fa-pause-circle',
		    'fas fa-paw' => 'fas fa-paw',
		    'fab fa-paypal' => 'fab fa-paypal',
		    'fas fa-peace' => 'fas fa-peace',
		    'fas fa-pen' => 'fas fa-pen',
		    'fas fa-pen-alt' => 'fas fa-pen-alt',
		    'fas fa-pen-fancy' => 'fas fa-pen-fancy',
		    'fas fa-pen-nib' => 'fas fa-pen-nib',
		    'fas fa-pen-square' => 'fas fa-pen-square',
		    'fas fa-pencil-alt' => 'fas fa-pencil-alt',
		    'fas fa-pencil-ruler' => 'fas fa-pencil-ruler',
		    'fab fa-penny-arcade' => 'fab fa-penny-arcade',
		    'fas fa-people-carry' => 'fas fa-people-carry',
		    'fas fa-pepper-hot' => 'fas fa-pepper-hot',
		    'fas fa-percent' => 'fas fa-percent',
		    'fas fa-percentage' => 'fas fa-percentage',
		    'fab fa-periscope' => 'fab fa-periscope',
		    'fas fa-person-booth' => 'fas fa-person-booth',
		    'fab fa-phabricator' => 'fab fa-phabricator',
		    'fab fa-phoenix-framework' => 'fab fa-phoenix-framework',
		    'fab fa-phoenix-squadron' => 'fab fa-phoenix-squadron',
		    'fas fa-phone' => 'fas fa-phone',
		    'fas fa-phone-alt' => 'fas fa-phone-alt',
		    'fas fa-phone-slash' => 'fas fa-phone-slash',
		    'fas fa-phone-square' => 'fas fa-phone-square',
		    'fas fa-phone-square-alt' => 'fas fa-phone-square-alt',
		    'fas fa-phone-volume' => 'fas fa-phone-volume',
		    'fas fa-photo-video' => 'fas fa-photo-video',
		    'fab fa-php' => 'fab fa-php',
		    'fab fa-pied-piper' => 'fab fa-pied-piper',
		    'fab fa-pied-piper-alt' => 'fab fa-pied-piper-alt',
		    'fab fa-pied-piper-hat' => 'fab fa-pied-piper-hat',
		    'fab fa-pied-piper-pp' => 'fab fa-pied-piper-pp',
		    'fas fa-piggy-bank' => 'fas fa-piggy-bank',
		    'fas fa-pills' => 'fas fa-pills',
		    'fab fa-pinterest' => 'fab fa-pinterest',
		    'fab fa-pinterest-p' => 'fab fa-pinterest-p',
		    'fab fa-pinterest-square' => 'fab fa-pinterest-square',
		    'fas fa-pizza-slice' => 'fas fa-pizza-slice',
		    'fas fa-place-of-worship' => 'fas fa-place-of-worship',
		    'fas fa-plane' => 'fas fa-plane',
		    'fas fa-plane-arrival' => 'fas fa-plane-arrival',
		    'fas fa-plane-departure' => 'fas fa-plane-departure',
		    'fas fa-play' => 'fas fa-play',
		    'fas fa-play-circle' => 'fas fa-play-circle',
		    'fab fa-playstation' => 'fab fa-playstation',
		    'fas fa-plug' => 'fas fa-plug',
		    'fas fa-plus' => 'fas fa-plus',
		    'fas fa-plus-circle' => 'fas fa-plus-circle',
		    'fas fa-plus-square' => 'fas fa-plus-square',
		    'fas fa-podcast' => 'fas fa-podcast',
		    'fas fa-poll' => 'fas fa-poll',
		    'fas fa-poll-h' => 'fas fa-poll-h',
		    'fas fa-poo' => 'fas fa-poo',
		    'fas fa-poo-storm' => 'fas fa-poo-storm',
		    'fas fa-poop' => 'fas fa-poop',
		    'fas fa-portrait' => 'fas fa-portrait',
		    'fas fa-pound-sign' => 'fas fa-pound-sign',
		    'fas fa-power-off' => 'fas fa-power-off',
		    'fas fa-pray' => 'fas fa-pray',
		    'fas fa-praying-hands' => 'fas fa-praying-hands',
		    'fas fa-prescription' => 'fas fa-prescription',
		    'fas fa-prescription-bottle' => 'fas fa-prescription-bottle',
		    'fas fa-prescription-bottle-alt' => 'fas fa-prescription-bottle-alt',
		    'fas fa-print' => 'fas fa-print',
		    'fas fa-procedures' => 'fas fa-procedures',
		    'fab fa-product-hunt' => 'fab fa-product-hunt',
		    'fas fa-project-diagram' => 'fas fa-project-diagram',
		    'fab fa-pushed' => 'fab fa-pushed',
		    'fas fa-puzzle-piece' => 'fas fa-puzzle-piece',
		    'fab fa-python' => 'fab fa-python',
		    'fab fa-qq' => 'fab fa-qq',
		    'fas fa-qrcode' => 'fas fa-qrcode',
		    'fas fa-question' => 'fas fa-question',
		    'fas fa-question-circle' => 'fas fa-question-circle',
		    'fas fa-quidditch' => 'fas fa-quidditch',
		    'fab fa-quinscape' => 'fab fa-quinscape',
		    'fab fa-quora' => 'fab fa-quora',
		    'fas fa-quote-left' => 'fas fa-quote-left',
		    'fas fa-quote-right' => 'fas fa-quote-right',
		    'fas fa-quran' => 'fas fa-quran',
		    'fab fa-r-project' => 'fab fa-r-project',
		    'fas fa-radiation' => 'fas fa-radiation',
		    'fas fa-radiation-alt' => 'fas fa-radiation-alt',
		    'fas fa-rainbow' => 'fas fa-rainbow',
		    'fas fa-random' => 'fas fa-random',
		    'fab fa-raspberry-pi' => 'fab fa-raspberry-pi',
		    'fab fa-ravelry' => 'fab fa-ravelry',
		    'fab fa-react' => 'fab fa-react',
		    'fab fa-reacteurope' => 'fab fa-reacteurope',
		    'fab fa-readme' => 'fab fa-readme',
		    'fab fa-rebel' => 'fab fa-rebel',
		    'fas fa-receipt' => 'fas fa-receipt',
		    'fas fa-recycle' => 'fas fa-recycle',
		    'fab fa-red-river' => 'fab fa-red-river',
		    'fab fa-reddit' => 'fab fa-reddit',
		    'fab fa-reddit-alien' => 'fab fa-reddit-alien',
		    'fab fa-reddit-square' => 'fab fa-reddit-square',
		    'fab fa-redhat' => 'fab fa-redhat',
		    'fas fa-redo' => 'fas fa-redo',
		    'fas fa-redo-alt' => 'fas fa-redo-alt',
		    'fas fa-registered' => 'fas fa-registered',
		    'fas fa-remove-format' => 'fas fa-remove-format',
		    'fab fa-renren' => 'fab fa-renren',
		    'fas fa-reply' => 'fas fa-reply',
		    'fas fa-reply-all' => 'fas fa-reply-all',
		    'fab fa-replyd' => 'fab fa-replyd',
		    'fas fa-republican' => 'fas fa-republican',
		    'fab fa-researchgate' => 'fab fa-researchgate',
		    'fab fa-resolving' => 'fab fa-resolving',
		    'fas fa-restroom' => 'fas fa-restroom',
		    'fas fa-retweet' => 'fas fa-retweet',
		    'fab fa-rev' => 'fab fa-rev',
		    'fas fa-ribbon' => 'fas fa-ribbon',
		    'fas fa-ring' => 'fas fa-ring',
		    'fas fa-road' => 'fas fa-road',
		    'fas fa-robot' => 'fas fa-robot',
		    'fas fa-rocket' => 'fas fa-rocket',
		    'fab fa-rocketchat' => 'fab fa-rocketchat',
		    'fab fa-rockrms' => 'fab fa-rockrms',
		    'fas fa-route' => 'fas fa-route',
		    'fas fa-rss' => 'fas fa-rss',
		    'fas fa-rss-square' => 'fas fa-rss-square',
		    'fas fa-ruble-sign' => 'fas fa-ruble-sign',
		    'fas fa-ruler' => 'fas fa-ruler',
		    'fas fa-ruler-combined' => 'fas fa-ruler-combined',
		    'fas fa-ruler-horizontal' => 'fas fa-ruler-horizontal',
		    'fas fa-ruler-vertical' => 'fas fa-ruler-vertical',
		    'fas fa-running' => 'fas fa-running',
		    'fas fa-rupee-sign' => 'fas fa-rupee-sign',
		    'fas fa-sad-cry' => 'fas fa-sad-cry',
		    'fas fa-sad-tear' => 'fas fa-sad-tear',
		    'fab fa-safari' => 'fab fa-safari',
		    'fab fa-salesforce' => 'fab fa-salesforce',
		    'fab fa-sass' => 'fab fa-sass',
		    'fas fa-satellite' => 'fas fa-satellite',
		    'fas fa-satellite-dish' => 'fas fa-satellite-dish',
		    'fas fa-save' => 'fas fa-save',
		    'fab fa-schlix' => 'fab fa-schlix',
		    'fas fa-school' => 'fas fa-school',
		    'fas fa-screwdriver' => 'fas fa-screwdriver',
		    'fab fa-scribd' => 'fab fa-scribd',
		    'fas fa-scroll' => 'fas fa-scroll',
		    'fas fa-sd-card' => 'fas fa-sd-card',
		    'fas fa-search' => 'fas fa-search',
		    'fas fa-search-dollar' => 'fas fa-search-dollar',
		    'fas fa-search-location' => 'fas fa-search-location',
		    'fas fa-search-minus' => 'fas fa-search-minus',
		    'fas fa-search-plus' => 'fas fa-search-plus',
		    'fab fa-searchengin' => 'fab fa-searchengin',
		    'fas fa-seedling' => 'fas fa-seedling',
		    'fab fa-sellcast' => 'fab fa-sellcast',
		    'fab fa-sellsy' => 'fab fa-sellsy',
		    'fas fa-server' => 'fas fa-server',
		    'fab fa-servicestack' => 'fab fa-servicestack',
		    'fas fa-shapes' => 'fas fa-shapes',
		    'fas fa-share' => 'fas fa-share',
		    'fas fa-share-alt' => 'fas fa-share-alt',
		    'fas fa-share-alt-square' => 'fas fa-share-alt-square',
		    'fas fa-share-square' => 'fas fa-share-square',
		    'fas fa-shekel-sign' => 'fas fa-shekel-sign',
		    'fas fa-shield-alt' => 'fas fa-shield-alt',
		    'fas fa-ship' => 'fas fa-ship',
		    'fas fa-shipping-fast' => 'fas fa-shipping-fast',
		    'fab fa-shirtsinbulk' => 'fab fa-shirtsinbulk',
		    'fas fa-shoe-prints' => 'fas fa-shoe-prints',
		    'fas fa-shopping-bag' => 'fas fa-shopping-bag',
		    'fas fa-shopping-basket' => 'fas fa-shopping-basket',
		    'fas fa-shopping-cart' => 'fas fa-shopping-cart',
		    'fab fa-shopware' => 'fab fa-shopware',
		    'fas fa-shower' => 'fas fa-shower',
		    'fas fa-shuttle-van' => 'fas fa-shuttle-van',
		    'fas fa-sign' => 'fas fa-sign',
		    'fas fa-sign-in-alt' => 'fas fa-sign-in-alt',
		    'fas fa-sign-language' => 'fas fa-sign-language',
		    'fas fa-sign-out-alt' => 'fas fa-sign-out-alt',
		    'fas fa-signal' => 'fas fa-signal',
		    'fas fa-signature' => 'fas fa-signature',
		    'fas fa-sim-card' => 'fas fa-sim-card',
		    'fab fa-simplybuilt' => 'fab fa-simplybuilt',
		    'fab fa-sistrix' => 'fab fa-sistrix',
		    'fas fa-sitemap' => 'fas fa-sitemap',
		    'fab fa-sith' => 'fab fa-sith',
		    'fas fa-skating' => 'fas fa-skating',
		    'fab fa-sketch' => 'fab fa-sketch',
		    'fas fa-skiing' => 'fas fa-skiing',
		    'fas fa-skiing-nordic' => 'fas fa-skiing-nordic',
		    'fas fa-skull' => 'fas fa-skull',
		    'fas fa-skull-crossbones' => 'fas fa-skull-crossbones',
		    'fab fa-skyatlas' => 'fab fa-skyatlas',
		    'fab fa-skype' => 'fab fa-skype',
		    'fab fa-slack' => 'fab fa-slack',
		    'fab fa-slack-hash' => 'fab fa-slack-hash',
		    'fas fa-slash' => 'fas fa-slash',
		    'fas fa-sleigh' => 'fas fa-sleigh',
		    'fas fa-sliders-h' => 'fas fa-sliders-h',
		    'fab fa-slideshare' => 'fab fa-slideshare',
		    'fas fa-smile' => 'fas fa-smile',
		    'fas fa-smile-beam' => 'fas fa-smile-beam',
		    'fas fa-smile-wink' => 'fas fa-smile-wink',
		    'fas fa-smog' => 'fas fa-smog',
		    'fas fa-smoking' => 'fas fa-smoking',
		    'fas fa-smoking-ban' => 'fas fa-smoking-ban',
		    'fas fa-sms' => 'fas fa-sms',
		    'fab fa-snapchat' => 'fab fa-snapchat',
		    'fab fa-snapchat-ghost' => 'fab fa-snapchat-ghost',
		    'fab fa-snapchat-square' => 'fab fa-snapchat-square',
		    'fas fa-snowboarding' => 'fas fa-snowboarding',
		    'fas fa-snowflake' => 'fas fa-snowflake',
		    'fas fa-snowman' => 'fas fa-snowman',
		    'fas fa-snowplow' => 'fas fa-snowplow',
		    'fas fa-socks' => 'fas fa-socks',
		    'fas fa-solar-panel' => 'fas fa-solar-panel',
		    'fas fa-sort' => 'fas fa-sort',
		    'fas fa-sort-alpha-down' => 'fas fa-sort-alpha-down',
		    'fas fa-sort-alpha-down-alt' => 'fas fa-sort-alpha-down-alt',
		    'fas fa-sort-alpha-up' => 'fas fa-sort-alpha-up',
		    'fas fa-sort-alpha-up-alt' => 'fas fa-sort-alpha-up-alt',
		    'fas fa-sort-amount-down' => 'fas fa-sort-amount-down',
		    'fas fa-sort-amount-down-alt' => 'fas fa-sort-amount-down-alt',
		    'fas fa-sort-amount-up' => 'fas fa-sort-amount-up',
		    'fas fa-sort-amount-up-alt' => 'fas fa-sort-amount-up-alt',
		    'fas fa-sort-down' => 'fas fa-sort-down',
		    'fas fa-sort-numeric-down' => 'fas fa-sort-numeric-down',
		    'fas fa-sort-numeric-down-alt' => 'fas fa-sort-numeric-down-alt',
		    'fas fa-sort-numeric-up' => 'fas fa-sort-numeric-up',
		    'fas fa-sort-numeric-up-alt' => 'fas fa-sort-numeric-up-alt',
		    'fas fa-sort-up' => 'fas fa-sort-up',
		    'fab fa-soundcloud' => 'fab fa-soundcloud',
		    'fab fa-sourcetree' => 'fab fa-sourcetree',
		    'fas fa-spa' => 'fas fa-spa',
		    'fas fa-space-shuttle' => 'fas fa-space-shuttle',
		    'fab fa-speakap' => 'fab fa-speakap',
		    'fab fa-speaker-deck' => 'fab fa-speaker-deck',
		    'fas fa-spell-check' => 'fas fa-spell-check',
		    'fas fa-spider' => 'fas fa-spider',
		    'fas fa-spinner' => 'fas fa-spinner',
		    'fas fa-splotch' => 'fas fa-splotch',
		    'fab fa-spotify' => 'fab fa-spotify',
		    'fas fa-spray-can' => 'fas fa-spray-can',
		    'fas fa-square' => 'fas fa-square',
		    'fas fa-square-full' => 'fas fa-square-full',
		    'fas fa-square-root-alt' => 'fas fa-square-root-alt',
		    'fab fa-squarespace' => 'fab fa-squarespace',
		    'fab fa-stack-exchange' => 'fab fa-stack-exchange',
		    'fab fa-stack-overflow' => 'fab fa-stack-overflow',
		    'fab fa-stackpath' => 'fab fa-stackpath',
		    'fas fa-stamp' => 'fas fa-stamp',
		    'fas fa-star' => 'fas fa-star',
		    'fas fa-star-and-crescent' => 'fas fa-star-and-crescent',
		    'fas fa-star-half' => 'fas fa-star-half',
		    'fas fa-star-half-alt' => 'fas fa-star-half-alt',
		    'fas fa-star-of-david' => 'fas fa-star-of-david',
		    'fas fa-star-of-life' => 'fas fa-star-of-life',
		    'fab fa-staylinked' => 'fab fa-staylinked',
		    'fab fa-steam' => 'fab fa-steam',
		    'fab fa-steam-square' => 'fab fa-steam-square',
		    'fab fa-steam-symbol' => 'fab fa-steam-symbol',
		    'fas fa-step-backward' => 'fas fa-step-backward',
		    'fas fa-step-forward' => 'fas fa-step-forward',
		    'fas fa-stethoscope' => 'fas fa-stethoscope',
		    'fab fa-sticker-mule' => 'fab fa-sticker-mule',
		    'fas fa-sticky-note' => 'fas fa-sticky-note',
		    'fas fa-stop' => 'fas fa-stop',
		    'fas fa-stop-circle' => 'fas fa-stop-circle',
		    'fas fa-stopwatch' => 'fas fa-stopwatch',
		    'fas fa-store' => 'fas fa-store',
		    'fas fa-store-alt' => 'fas fa-store-alt',
		    'fab fa-strava' => 'fab fa-strava',
		    'fas fa-stream' => 'fas fa-stream',
		    'fas fa-street-view' => 'fas fa-street-view',
		    'fas fa-strikethrough' => 'fas fa-strikethrough',
		    'fab fa-stripe' => 'fab fa-stripe',
		    'fab fa-stripe-s' => 'fab fa-stripe-s',
		    'fas fa-stroopwafel' => 'fas fa-stroopwafel',
		    'fab fa-studiovinari' => 'fab fa-studiovinari',
		    'fab fa-stumbleupon' => 'fab fa-stumbleupon',
		    'fab fa-stumbleupon-circle' => 'fab fa-stumbleupon-circle',
		    'fas fa-subscript' => 'fas fa-subscript',
		    'fas fa-subway' => 'fas fa-subway',
		    'fas fa-suitcase' => 'fas fa-suitcase',
		    'fas fa-suitcase-rolling' => 'fas fa-suitcase-rolling',
		    'fas fa-sun' => 'fas fa-sun',
		    'fab fa-superpowers' => 'fab fa-superpowers',
		    'fas fa-superscript' => 'fas fa-superscript',
		    'fab fa-supple' => 'fab fa-supple',
		    'fas fa-surprise' => 'fas fa-surprise',
		    'fab fa-suse' => 'fab fa-suse',
		    'fas fa-swatchbook' => 'fas fa-swatchbook',
		    'fas fa-swimmer' => 'fas fa-swimmer',
		    'fas fa-swimming-pool' => 'fas fa-swimming-pool',
		    'fab fa-symfony' => 'fab fa-symfony',
		    'fas fa-synagogue' => 'fas fa-synagogue',
		    'fas fa-sync' => 'fas fa-sync',
		    'fas fa-sync-alt' => 'fas fa-sync-alt',
		    'fas fa-syringe' => 'fas fa-syringe',
		    'fas fa-table' => 'fas fa-table',
		    'fas fa-table-tennis' => 'fas fa-table-tennis',
		    'fas fa-tablet' => 'fas fa-tablet',
		    'fas fa-tablet-alt' => 'fas fa-tablet-alt',
		    'fas fa-tablets' => 'fas fa-tablets',
		    'fas fa-tachometer-alt' => 'fas fa-tachometer-alt',
		    'fas fa-tag' => 'fas fa-tag',
		    'fas fa-tags' => 'fas fa-tags',
		    'fas fa-tape' => 'fas fa-tape',
		    'fas fa-tasks' => 'fas fa-tasks',
		    'fas fa-taxi' => 'fas fa-taxi',
		    'fab fa-teamspeak' => 'fab fa-teamspeak',
		    'fas fa-teeth' => 'fas fa-teeth',
		    'fas fa-teeth-open' => 'fas fa-teeth-open',
		    'fab fa-telegram' => 'fab fa-telegram',
		    'fab fa-telegram-plane' => 'fab fa-telegram-plane',
		    'fas fa-temperature-high' => 'fas fa-temperature-high',
		    'fas fa-temperature-low' => 'fas fa-temperature-low',
		    'fab fa-tencent-weibo' => 'fab fa-tencent-weibo',
		    'fas fa-tenge' => 'fas fa-tenge',
		    'fas fa-terminal' => 'fas fa-terminal',
		    'fas fa-text-height' => 'fas fa-text-height',
		    'fas fa-text-width' => 'fas fa-text-width',
		    'fas fa-th' => 'fas fa-th',
		    'fas fa-th-large' => 'fas fa-th-large',
		    'fas fa-th-list' => 'fas fa-th-list',
		    'fab fa-the-red-yeti' => 'fab fa-the-red-yeti',
		    'fas fa-theater-masks' => 'fas fa-theater-masks',
		    'fab fa-themeco' => 'fab fa-themeco',
		    'fab fa-themeisle' => 'fab fa-themeisle',
		    'fas fa-thermometer' => 'fas fa-thermometer',
		    'fas fa-thermometer-empty' => 'fas fa-thermometer-empty',
		    'fas fa-thermometer-full' => 'fas fa-thermometer-full',
		    'fas fa-thermometer-half' => 'fas fa-thermometer-half',
		    'fas fa-thermometer-quarter' => 'fas fa-thermometer-quarter',
		    'fas fa-thermometer-three-quarters' => 'fas fa-thermometer-three-quarters',
		    'fab fa-think-peaks' => 'fab fa-think-peaks',
		    'fas fa-thumbs-down' => 'fas fa-thumbs-down',
		    'fas fa-thumbs-up' => 'fas fa-thumbs-up',
		    'fas fa-thumbtack' => 'fas fa-thumbtack',
		    'fas fa-ticket-alt' => 'fas fa-ticket-alt',
		    'fas fa-times' => 'fas fa-times',
		    'fas fa-times-circle' => 'fas fa-times-circle',
		    'fas fa-tint' => 'fas fa-tint',
		    'fas fa-tint-slash' => 'fas fa-tint-slash',
		    'fas fa-tired' => 'fas fa-tired',
		    'fas fa-toggle-off' => 'fas fa-toggle-off',
		    'fas fa-toggle-on' => 'fas fa-toggle-on',
		    'fas fa-toilet' => 'fas fa-toilet',
		    'fas fa-toilet-paper' => 'fas fa-toilet-paper',
		    'fas fa-toolbox' => 'fas fa-toolbox',
		    'fas fa-tools' => 'fas fa-tools',
		    'fas fa-tooth' => 'fas fa-tooth',
		    'fas fa-torah' => 'fas fa-torah',
		    'fas fa-torii-gate' => 'fas fa-torii-gate',
		    'fas fa-tractor' => 'fas fa-tractor',
		    'fab fa-trade-federation' => 'fab fa-trade-federation',
		    'fas fa-trademark' => 'fas fa-trademark',
		    'fas fa-traffic-light' => 'fas fa-traffic-light',
		    'fas fa-train' => 'fas fa-train',
		    'fas fa-tram' => 'fas fa-tram',
		    'fas fa-transgender' => 'fas fa-transgender',
		    'fas fa-transgender-alt' => 'fas fa-transgender-alt',
		    'fas fa-trash' => 'fas fa-trash',
		    'fas fa-trash-alt' => 'fas fa-trash-alt',
		    'fas fa-trash-restore' => 'fas fa-trash-restore',
		    'fas fa-trash-restore-alt' => 'fas fa-trash-restore-alt',
		    'fas fa-tree' => 'fas fa-tree',
		    'fab fa-trello' => 'fab fa-trello',
		    'fab fa-tripadvisor' => 'fab fa-tripadvisor',
		    'fas fa-trophy' => 'fas fa-trophy',
		    'fas fa-truck' => 'fas fa-truck',
		    'fas fa-truck-loading' => 'fas fa-truck-loading',
		    'fas fa-truck-monster' => 'fas fa-truck-monster',
		    'fas fa-truck-moving' => 'fas fa-truck-moving',
		    'fas fa-truck-pickup' => 'fas fa-truck-pickup',
		    'fas fa-tshirt' => 'fas fa-tshirt',
		    'fas fa-tty' => 'fas fa-tty',
		    'fab fa-tumblr' => 'fab fa-tumblr',
		    'fab fa-tumblr-square' => 'fab fa-tumblr-square',
		    'fas fa-tv' => 'fas fa-tv',
		    'fab fa-twitch' => 'fab fa-twitch',
		    'fab fa-twitter' => 'fab fa-twitter',
		    'fab fa-twitter-square' => 'fab fa-twitter-square',
		    'fab fa-typo3' => 'fab fa-typo3',
		    'fab fa-uber' => 'fab fa-uber',
		    'fab fa-ubuntu' => 'fab fa-ubuntu',
		    'fab fa-uikit' => 'fab fa-uikit',
		    'fas fa-umbrella' => 'fas fa-umbrella',
		    'fas fa-umbrella-beach' => 'fas fa-umbrella-beach',
		    'fas fa-underline' => 'fas fa-underline',
		    'fas fa-undo' => 'fas fa-undo',
		    'fas fa-undo-alt' => 'fas fa-undo-alt',
		    'fab fa-uniregistry' => 'fab fa-uniregistry',
		    'fas fa-universal-access' => 'fas fa-universal-access',
		    'fas fa-university' => 'fas fa-university',
		    'fas fa-unlink' => 'fas fa-unlink',
		    'fas fa-unlock' => 'fas fa-unlock',
		    'fas fa-unlock-alt' => 'fas fa-unlock-alt',
		    'fab fa-untappd' => 'fab fa-untappd',
		    'fas fa-upload' => 'fas fa-upload',
		    'fab fa-ups' => 'fab fa-ups',
		    'fab fa-usb' => 'fab fa-usb',
		    'fas fa-user' => 'fas fa-user',
		    'fas fa-user-alt' => 'fas fa-user-alt',
		    'fas fa-user-alt-slash' => 'fas fa-user-alt-slash',
		    'fas fa-user-astronaut' => 'fas fa-user-astronaut',
		    'fas fa-user-check' => 'fas fa-user-check',
		    'fas fa-user-circle' => 'fas fa-user-circle',
		    'fas fa-user-clock' => 'fas fa-user-clock',
		    'fas fa-user-cog' => 'fas fa-user-cog',
		    'fas fa-user-edit' => 'fas fa-user-edit',
		    'fas fa-user-friends' => 'fas fa-user-friends',
		    'fas fa-user-graduate' => 'fas fa-user-graduate',
		    'fas fa-user-injured' => 'fas fa-user-injured',
		    'fas fa-user-lock' => 'fas fa-user-lock',
		    'fas fa-user-md' => 'fas fa-user-md',
		    'fas fa-user-minus' => 'fas fa-user-minus',
		    'fas fa-user-ninja' => 'fas fa-user-ninja',
		    'fas fa-user-nurse' => 'fas fa-user-nurse',
		    'fas fa-user-plus' => 'fas fa-user-plus',
		    'fas fa-user-secret' => 'fas fa-user-secret',
		    'fas fa-user-shield' => 'fas fa-user-shield',
		    'fas fa-user-slash' => 'fas fa-user-slash',
		    'fas fa-user-tag' => 'fas fa-user-tag',
		    'fas fa-user-tie' => 'fas fa-user-tie',
		    'fas fa-user-times' => 'fas fa-user-times',
		    'fas fa-users' => 'fas fa-users',
		    'fas fa-users-cog' => 'fas fa-users-cog',
		    'fab fa-usps' => 'fab fa-usps',
		    'fab fa-ussunnah' => 'fab fa-ussunnah',
		    'fas fa-utensil-spoon' => 'fas fa-utensil-spoon',
		    'fas fa-utensils' => 'fas fa-utensils',
		    'fab fa-vaadin' => 'fab fa-vaadin',
		    'fas fa-vector-square' => 'fas fa-vector-square',
		    'fas fa-venus' => 'fas fa-venus',
		    'fas fa-venus-double' => 'fas fa-venus-double',
		    'fas fa-venus-mars' => 'fas fa-venus-mars',
		    'fab fa-viacoin' => 'fab fa-viacoin',
		    'fab fa-viadeo' => 'fab fa-viadeo',
		    'fab fa-viadeo-square' => 'fab fa-viadeo-square',
		    'fas fa-vial' => 'fas fa-vial',
		    'fas fa-vials' => 'fas fa-vials',
		    'fab fa-viber' => 'fab fa-viber',
		    'fas fa-video' => 'fas fa-video',
		    'fas fa-video-slash' => 'fas fa-video-slash',
		    'fas fa-vihara' => 'fas fa-vihara',
		    'fab fa-vimeo' => 'fab fa-vimeo',
		    'fab fa-vimeo-square' => 'fab fa-vimeo-square',
		    'fab fa-vimeo-v' => 'fab fa-vimeo-v',
		    'fab fa-vine' => 'fab fa-vine',
		    'fab fa-vk' => 'fab fa-vk',
		    'fab fa-vnv' => 'fab fa-vnv',
		    'fas fa-voicemail' => 'fas fa-voicemail',
		    'fas fa-volleyball-ball' => 'fas fa-volleyball-ball',
		    'fas fa-volume-down' => 'fas fa-volume-down',
		    'fas fa-volume-mute' => 'fas fa-volume-mute',
		    'fas fa-volume-off' => 'fas fa-volume-off',
		    'fas fa-volume-up' => 'fas fa-volume-up',
		    'fas fa-vote-yea' => 'fas fa-vote-yea',
		    'fas fa-vr-cardboard' => 'fas fa-vr-cardboard',
		    'fab fa-vuejs' => 'fab fa-vuejs',
		    'fas fa-walking' => 'fas fa-walking',
		    'fas fa-wallet' => 'fas fa-wallet',
		    'fas fa-warehouse' => 'fas fa-warehouse',
		    'fas fa-water' => 'fas fa-water',
		    'fas fa-wave-square' => 'fas fa-wave-square',
		    'fab fa-waze' => 'fab fa-waze',
		    'fab fa-weebly' => 'fab fa-weebly',
		    'fab fa-weibo' => 'fab fa-weibo',
		    'fas fa-weight' => 'fas fa-weight',
		    'fas fa-weight-hanging' => 'fas fa-weight-hanging',
		    'fab fa-weixin' => 'fab fa-weixin',
		    'fab fa-whatsapp' => 'fab fa-whatsapp',
		    'fab fa-whatsapp-square' => 'fab fa-whatsapp-square',
		    'fas fa-wheelchair' => 'fas fa-wheelchair',
		    'fab fa-whmcs' => 'fab fa-whmcs',
		    'fas fa-wifi' => 'fas fa-wifi',
		    'fab fa-wikipedia-w' => 'fab fa-wikipedia-w',
		    'fas fa-wind' => 'fas fa-wind',
		    'fas fa-window-close' => 'fas fa-window-close',
		    'fas fa-window-maximize' => 'fas fa-window-maximize',
		    'fas fa-window-minimize' => 'fas fa-window-minimize',
		    'fas fa-window-restore' => 'fas fa-window-restore',
		    'fab fa-windows' => 'fab fa-windows',
		    'fas fa-wine-bottle' => 'fas fa-wine-bottle',
		    'fas fa-wine-glass' => 'fas fa-wine-glass',
		    'fas fa-wine-glass-alt' => 'fas fa-wine-glass-alt',
		    'fab fa-wix' => 'fab fa-wix',
		    'fab fa-wizards-of-the-coast' => 'fab fa-wizards-of-the-coast',
		    'fab fa-wolf-pack-battalion' => 'fab fa-wolf-pack-battalion',
		    'fas fa-won-sign' => 'fas fa-won-sign',
		    'fab fa-wordpress' => 'fab fa-wordpress',
		    'fab fa-wordpress-simple' => 'fab fa-wordpress-simple',
		    'fab fa-wpbeginner' => 'fab fa-wpbeginner',
		    'fab fa-wpexplorer' => 'fab fa-wpexplorer',
		    'fab fa-wpforms' => 'fab fa-wpforms',
		    'fab fa-wpressr' => 'fab fa-wpressr',
		    'fas fa-wrench' => 'fas fa-wrench',
		    'fas fa-x-ray' => 'fas fa-x-ray',
		    'fab fa-xbox' => 'fab fa-xbox',
		    'fab fa-xing' => 'fab fa-xing',
		    'fab fa-xing-square' => 'fab fa-xing-square',
		    'fab fa-y-combinator' => 'fab fa-y-combinator',
		    'fab fa-yahoo' => 'fab fa-yahoo',
		    'fab fa-yammer' => 'fab fa-yammer',
		    'fab fa-yandex' => 'fab fa-yandex',
		    'fab fa-yandex-international' => 'fab fa-yandex-international',
		    'fab fa-yarn' => 'fab fa-yarn',
		    'fab fa-yelp' => 'fab fa-yelp',
		    'fas fa-yen-sign' => 'fas fa-yen-sign',
		    'fas fa-yin-yang' => 'fas fa-yin-yang',
		    'fab fa-yoast' => 'fab fa-yoast',
		    'fab fa-youtube' => 'fab fa-youtube',
		    'fab fa-youtube-square' => 'fab fa-youtube-square',
		    'fab fa-zhihu' => 'fab fa-zhihu'
			);
		
	}

    function get_linear_icons_icons()
    {
        return
            array(
                'lnr lnr-home' => 'lnr lnr-home',
                'lnr lnr-apartment' => 'lnr lnr-apartment',
                'lnr lnr-pencil' => 'lnr lnr-pencil',
                'lnr lnr-magic-wand' => 'lnr lnr-magic-wand',
                'lnr lnr-drop' => 'lnr lnr-drop',
                'lnr lnr-lighter' => 'lnr lnr-lighter',
                'lnr lnr-poop' => 'lnr lnr-poop',
                'lnr lnr-sun' => 'lnr lnr-sun',
                'lnr lnr-moon' => 'lnr lnr-moon',
                'lnr lnr-cloud' => 'lnr lnr-cloud',
                'lnr lnr-cloud-upload' => 'lnr lnr-cloud-upload',
                'lnr lnr-cloud-download' => 'lnr lnr-cloud-download',
                'lnr lnr-cloud-sync' => 'lnr lnr-cloud-sync',
                'lnr lnr-cloud-check' => 'lnr lnr-cloud-check',
                'lnr lnr-database' => 'lnr lnr-database',
                'lnr lnr-lock' => 'lnr lnr-lock',
                'lnr lnr-cog' => 'lnr lnr-cog',
                'lnr lnr-trash' => 'lnr lnr-trash',
                'lnr lnr-dice' => 'lnr lnr-dice',
                'lnr lnr-heart' => 'lnr lnr-heart',
                'lnr lnr-star' => 'lnr lnr-star',
                'lnr lnr-star-half' => 'lnr lnr-star-half',
                'lnr lnr-star-empty' => 'lnr lnr-star-empty',
                'lnr lnr-flag' => 'lnr lnr-flag',
                'lnr lnr-envelope' => 'lnr lnr-envelope',
                'lnr lnr-paperclip' => 'lnr lnr-paperclip',
                'lnr lnr-inbox' => 'lnr lnr-inbox',
                'lnr lnr-eye' => 'lnr lnr-eye',
                'lnr lnr-printer' => 'lnr lnr-printer',
                'lnr lnr-file-empty' => 'lnr lnr-file-empty',
                'lnr lnr-file-add' => 'lnr lnr-file-add',
                'lnr lnr-enter' => 'lnr lnr-enter',
                'lnr lnr-exit' => 'lnr lnr-exit',
                'lnr lnr-graduation-hat' => 'lnr lnr-graduation-hat',
                'lnr lnr-license' => 'lnr lnr-license',
                'lnr lnr-music-note' => 'lnr lnr-music-note',
                'lnr lnr-film-play' => 'lnr lnr-film-play',
                'lnr lnr-camera-video' => 'lnr lnr-camera-video',
                'lnr lnr-camera' => 'lnr lnr-camera',
                'lnr lnr-picture' => 'lnr lnr-picture',
                'lnr lnr-book' => 'lnr lnr-book',
                'lnr lnr-bookmark' => 'lnr lnr-bookmark',
                'lnr lnr-user' => 'lnr lnr-user',
                'lnr lnr-users' => 'lnr lnr-users',
                'lnr lnr-shirt' => 'lnr lnr-shirt',
                'lnr lnr-store' => 'lnr lnr-store',
                'lnr lnr-cart' => 'lnr lnr-cart',
                'lnr lnr-tag' => 'lnr lnr-tag',
                'lnr lnr-phone-handset' => 'lnr lnr-phone-handset',
                'lnr lnr-phone' => 'lnr lnr-phone',
                'lnr lnr-pushpin' => 'lnr lnr-pushpin',
                'lnr lnr-map-marker' => 'lnr lnr-map-marker',
                'lnr lnr-map' => 'lnr lnr-map',
                'lnr lnr-location' => 'lnr lnr-location',
                'lnr lnr-calendar-full' => 'lnr lnr-calendar-full',
                'lnr lnr-keyboard' => 'lnr lnr-keyboard',
                'lnr lnr-spell-check' => 'lnr lnr-spell-check',
                'lnr lnr-screen' => 'lnr lnr-screen',
                'lnr lnr-smartphone' => 'lnr lnr-smartphone',
                'lnr lnr-tablet' => 'lnr lnr-tablet',
                'lnr lnr-laptop' => 'lnr lnr-laptop',
                'lnr lnr-laptop-phone' => 'lnr lnr-laptop-phone',
                'lnr lnr-power-switch' => 'lnr lnr-power-switch',
                'lnr lnr-bubble' => 'lnr lnr-bubble',
                'lnr lnr-heart-pulse' => 'lnr lnr-heart-pulse',
                'lnr lnr-construction' => 'lnr lnr-construction',
                'lnr lnr-pie-chart' => 'lnr lnr-pie-chart',
                'lnr lnr-chart-bars' => 'lnr lnr-chart-bars',
                'lnr lnr-gift' => 'lnr lnr-gift',
                'lnr lnr-diamond' => 'lnr lnr-diamond',
                'lnr lnr-linearicons' => 'lnr lnr-linearicons',
                'lnr lnr-dinner' => 'lnr lnr-dinner',
                'lnr lnr-coffee-cup' => 'lnr lnr-coffee-cup',
                'lnr lnr-leaf' => 'lnr lnr-leaf',
                'lnr lnr-paw' => 'lnr lnr-paw',
                'lnr lnr-rocket' => 'lnr lnr-rocket',
                'lnr lnr-briefcase' => 'lnr lnr-briefcase',
                'lnr lnr-bus' => 'lnr lnr-bus',
                'lnr lnr-car' => 'lnr lnr-car',
                'lnr lnr-train' => 'lnr lnr-train',
                'lnr lnr-bicycle' => 'lnr lnr-bicycle',
                'lnr lnr-wheelchair' => 'lnr lnr-wheelchair',
                'lnr lnr-select' => 'lnr lnr-select',
                'lnr lnr-earth' => 'lnr lnr-earth',
                'lnr lnr-smile' => 'lnr lnr-smile',
                'lnr lnr-sad' => 'lnr lnr-sad',
                'lnr lnr-neutral' => 'lnr lnr-neutral',
                'lnr lnr-mustache' => 'lnr lnr-mustache',
                'lnr lnr-alarm' => 'lnr lnr-alarm',
                'lnr lnr-bullhorn' => 'lnr lnr-bullhorn',
                'lnr lnr-volume-high' => 'lnr lnr-volume-high',
                'lnr lnr-volume-medium' => 'lnr lnr-volume-medium',
                'lnr lnr-volume-low' => 'lnr lnr-volume-low',
                'lnr lnr-volume' => 'lnr lnr-volume',
                'lnr lnr-mic' => 'lnr lnr-mic',
                'lnr lnr-hourglass' => 'lnr lnr-hourglass',
                'lnr lnr-undo' => 'lnr lnr-undo',
                'lnr lnr-redo' => 'lnr lnr-redo',
                'lnr lnr-sync' => 'lnr lnr-sync',
                'lnr lnr-history' => 'lnr lnr-history',
                'lnr lnr-clock' => 'lnr lnr-clock',
                'lnr lnr-download' => 'lnr lnr-download',
                'lnr lnr-upload' => 'lnr lnr-upload',
                'lnr lnr-enter-down' => 'lnr lnr-enter-down',
                'lnr lnr-exit-up' => 'lnr lnr-exit-up',
                'lnr lnr-bug' => 'lnr lnr-bug',
                'lnr lnr-code' => 'lnr lnr-code',
                'lnr lnr-link' => 'lnr lnr-link',
                'lnr lnr-unlink' => 'lnr lnr-unlink',
                'lnr lnr-thumbs-up' => 'lnr lnr-thumbs-up',
                'lnr lnr-thumbs-down' => 'lnr lnr-thumbs-down',
                'lnr lnr-magnifier' => 'lnr lnr-magnifier',
                'lnr lnr-cross' => 'lnr lnr-cross',
                'lnr lnr-menu' => 'lnr lnr-menu',
                'lnr lnr-list' => 'lnr lnr-list',
                'lnr lnr-chevron-up' => 'lnr lnr-chevron-up',
                'lnr lnr-chevron-down' => 'lnr lnr-chevron-down',
                'lnr lnr-chevron-left' => 'lnr lnr-chevron-left',
                'lnr lnr-chevron-right' => 'lnr lnr-chevron-right',
                'lnr lnr-arrow-up' => 'lnr lnr-arrow-up',
                'lnr lnr-arrow-down' => 'lnr lnr-arrow-down',
                'lnr lnr-arrow-left' => 'lnr lnr-arrow-left',
                'lnr lnr-arrow-right' => 'lnr lnr-arrow-right',
                'lnr lnr-move' => 'lnr lnr-move',
                'lnr lnr-warning' => 'lnr lnr-warning',
                'lnr lnr-question-circle' => 'lnr lnr-question-circle',
                'lnr lnr-menu-circle' => 'lnr lnr-menu-circle',
                'lnr lnr-checkmark-circle' => 'lnr lnr-checkmark-circle',
                'lnr lnr-cross-circle' => 'lnr lnr-cross-circle',
                'lnr lnr-plus-circle' => 'lnr lnr-plus-circle',
                'lnr lnr-circle-minus' => 'lnr lnr-circle-minus',
                'lnr lnr-arrow-up-circle' => 'lnr lnr-arrow-up-circle',
                'lnr lnr-arrow-down-circle' => 'lnr lnr-arrow-down-circle',
                'lnr lnr-arrow-left-circle' => 'lnr lnr-arrow-left-circle',
                'lnr lnr-arrow-right-circle' => 'lnr lnr-arrow-right-circle',
                'lnr lnr-chevron-up-circle' => 'lnr lnr-chevron-up-circle',
                'lnr lnr-chevron-down-circle' => 'lnr lnr-chevron-down-circle',
                'lnr lnr-chevron-left-circle' => 'lnr lnr-chevron-left-circle',
                'lnr lnr-chevron-right-circle' => 'lnr lnr-chevron-right-circle',
                'lnr lnr-crop' => 'lnr lnr-crop',
                'lnr lnr-frame-expand' => 'lnr lnr-frame-expand',
                'lnr lnr-frame-contract' => 'lnr lnr-frame-contract',
                'lnr lnr-layers' => 'lnr lnr-layers',
                'lnr lnr-funnel' => 'lnr lnr-funnel',
                'lnr lnr-text-format' => 'lnr lnr-text-format',
                'lnr lnr-text-format-remove' => 'lnr lnr-text-format-remove',
                'lnr lnr-text-size' => 'lnr lnr-text-size',
                'lnr lnr-bold' => 'lnr lnr-bold',
                'lnr lnr-italic' => 'lnr lnr-italic',
                'lnr lnr-underline' => 'lnr lnr-underline',
                'lnr lnr-strikethrough' => 'lnr lnr-strikethrough',
                'lnr lnr-highlight' => 'lnr lnr-highlight',
                'lnr lnr-text-align-left' => 'lnr lnr-text-align-left',
                'lnr lnr-text-align-center' => 'lnr lnr-text-align-center',
                'lnr lnr-text-align-right' => 'lnr lnr-text-align-right',
                'lnr lnr-text-align-justify' => 'lnr lnr-text-align-justify',
                'lnr lnr-line-spacing' => 'lnr lnr-line-spacing',
                'lnr lnr-indent-increase' => 'lnr lnr-indent-increase',
                'lnr lnr-indent-decrease' => 'lnr lnr-indent-decrease',
                'lnr lnr-pilcrow' => 'lnr lnr-pilcrow',
                'lnr lnr-direction-ltr' => 'lnr lnr-direction-ltr',
                'lnr lnr-direction-rtl' => 'lnr lnr-direction-rtl',
                'lnr lnr-page-break' => 'lnr lnr-page-break',
                'lnr lnr-sort-alpha-asc' => 'lnr lnr-sort-alpha-asc',
                'lnr lnr-sort-amount-asc' => 'lnr lnr-sort-amount-asc',
                'lnr lnr-hand' => 'lnr lnr-hand',
                'lnr lnr-pointer-up' => 'lnr lnr-pointer-up',
                'lnr lnr-pointer-right' => 'lnr lnr-pointer-right',
                'lnr lnr-pointer-down' => 'lnr lnr-pointer-down',
                'lnr lnr-pointer-left' => 'lnr lnr-pointer-left'
            );
        
    }
}
